# -*- coding: utf-8 -*-
# flake8: noqa
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: protos/ydb_operation.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import any_pb2 as google_dot_protobuf_dot_any__pb2
from google.protobuf import duration_pb2 as google_dot_protobuf_dot_duration__pb2
from ydb._grpc.v3.protos.annotations import validation_pb2 as protos_dot_annotations_dot_validation__pb2
from ydb._grpc.v3.protos import ydb_common_pb2 as protos_dot_ydb__common__pb2
from ydb._grpc.v3.protos import ydb_issue_message_pb2 as protos_dot_ydb__issue__message__pb2
from ydb._grpc.v3.protos import ydb_status_codes_pb2 as protos_dot_ydb__status__codes__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='protos/ydb_operation.proto',
  package='Ydb.Operations',
  syntax='proto3',
  serialized_options=b'\n\010tech.ydbB\017OperationProtosZ=github.com/ydb-platform/ydb-go-genproto/protos/Ydb_Operations\370\001\001',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n\x1aprotos/ydb_operation.proto\x12\x0eYdb.Operations\x1a\x19google/protobuf/any.proto\x1a\x1egoogle/protobuf/duration.proto\x1a#protos/annotations/validation.proto\x1a\x17protos/ydb_common.proto\x1a\x1eprotos/ydb_issue_message.proto\x1a\x1dprotos/ydb_status_codes.proto\"\xb6\x03\n\x0fOperationParams\x12\x45\n\x0eoperation_mode\x18\x01 \x01(\x0e\x32-.Ydb.Operations.OperationParams.OperationMode\x12\x34\n\x11operation_timeout\x18\x02 \x01(\x0b\x32\x19.google.protobuf.Duration\x12/\n\x0c\x63\x61ncel_after\x18\x03 \x01(\x0b\x32\x19.google.protobuf.Duration\x12M\n\x06labels\x18\x04 \x03(\x0b\x32+.Ydb.Operations.OperationParams.LabelsEntryB\x10\xaa\xe6*\x05\n\x03\x18\x80\x01\xa2\xe6*\x03\x18\x80\x01\x12\x31\n\x10report_cost_info\x18\x05 \x01(\x0e\x32\x17.Ydb.FeatureFlag.Status\x1a-\n\x0bLabelsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"D\n\rOperationMode\x12\x1e\n\x1aOPERATION_MODE_UNSPECIFIED\x10\x00\x12\x08\n\x04SYNC\x10\x01\x12\t\n\x05\x41SYNC\x10\x02\"\'\n\x13GetOperationRequest\x12\x10\n\x02id\x18\x01 \x01(\tB\x04\x90\xe6*\x01\"D\n\x14GetOperationResponse\x12,\n\toperation\x18\x01 \x01(\x0b\x32\x19.Ydb.Operations.Operation\"*\n\x16\x43\x61ncelOperationRequest\x12\x10\n\x02id\x18\x01 \x01(\tB\x04\x90\xe6*\x01\"m\n\x17\x43\x61ncelOperationResponse\x12)\n\x06status\x18\x01 \x01(\x0e\x32\x19.Ydb.StatusIds.StatusCode\x12\'\n\x06issues\x18\x02 \x03(\x0b\x32\x17.Ydb.Issue.IssueMessage\"*\n\x16\x46orgetOperationRequest\x12\x10\n\x02id\x18\x01 \x01(\tB\x04\x90\xe6*\x01\"m\n\x17\x46orgetOperationResponse\x12)\n\x06status\x18\x01 \x01(\x0e\x32\x19.Ydb.StatusIds.StatusCode\x12\'\n\x06issues\x18\x02 \x03(\x0b\x32\x17.Ydb.Issue.IssueMessage\"R\n\x15ListOperationsRequest\x12\x12\n\x04kind\x18\x01 \x01(\tB\x04\x90\xe6*\x01\x12\x11\n\tpage_size\x18\x02 \x01(\x04\x12\x12\n\npage_token\x18\x03 \x01(\t\"\xb4\x01\n\x16ListOperationsResponse\x12)\n\x06status\x18\x01 \x01(\x0e\x32\x19.Ydb.StatusIds.StatusCode\x12\'\n\x06issues\x18\x02 \x03(\x0b\x32\x17.Ydb.Issue.IssueMessage\x12-\n\noperations\x18\x03 \x03(\x0b\x32\x19.Ydb.Operations.Operation\x12\x17\n\x0fnext_page_token\x18\x04 \x01(\t\"\xea\x01\n\tOperation\x12\n\n\x02id\x18\x01 \x01(\t\x12\r\n\x05ready\x18\x02 \x01(\x08\x12)\n\x06status\x18\x03 \x01(\x0e\x32\x19.Ydb.StatusIds.StatusCode\x12\'\n\x06issues\x18\x04 \x03(\x0b\x32\x17.Ydb.Issue.IssueMessage\x12$\n\x06result\x18\x05 \x01(\x0b\x32\x14.google.protobuf.Any\x12&\n\x08metadata\x18\x06 \x01(\x0b\x32\x14.google.protobuf.Any\x12 \n\tcost_info\x18\x07 \x01(\x0b\x32\r.Ydb.CostInfoB]\n\x08tech.ydbB\x0fOperationProtosZ=github.com/ydb-platform/ydb-go-genproto/protos/Ydb_Operations\xf8\x01\x01\x62\x06proto3'
  ,
  dependencies=[google_dot_protobuf_dot_any__pb2.DESCRIPTOR,google_dot_protobuf_dot_duration__pb2.DESCRIPTOR,protos_dot_annotations_dot_validation__pb2.DESCRIPTOR,protos_dot_ydb__common__pb2.DESCRIPTOR,protos_dot_ydb__issue__message__pb2.DESCRIPTOR,protos_dot_ydb__status__codes__pb2.DESCRIPTOR,])



_OPERATIONPARAMS_OPERATIONMODE = _descriptor.EnumDescriptor(
  name='OperationMode',
  full_name='Ydb.Operations.OperationParams.OperationMode',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='OPERATION_MODE_UNSPECIFIED', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='SYNC', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='ASYNC', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=601,
  serialized_end=669,
)
_sym_db.RegisterEnumDescriptor(_OPERATIONPARAMS_OPERATIONMODE)


_OPERATIONPARAMS_LABELSENTRY = _descriptor.Descriptor(
  name='LabelsEntry',
  full_name='Ydb.Operations.OperationParams.LabelsEntry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='Ydb.Operations.OperationParams.LabelsEntry.key', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='value', full_name='Ydb.Operations.OperationParams.LabelsEntry.value', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'8\001',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=554,
  serialized_end=599,
)

_OPERATIONPARAMS = _descriptor.Descriptor(
  name='OperationParams',
  full_name='Ydb.Operations.OperationParams',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='operation_mode', full_name='Ydb.Operations.OperationParams.operation_mode', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='operation_timeout', full_name='Ydb.Operations.OperationParams.operation_timeout', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='cancel_after', full_name='Ydb.Operations.OperationParams.cancel_after', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='labels', full_name='Ydb.Operations.OperationParams.labels', index=3,
      number=4, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\252\346*\005\n\003\030\200\001\242\346*\003\030\200\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='report_cost_info', full_name='Ydb.Operations.OperationParams.report_cost_info', index=4,
      number=5, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_OPERATIONPARAMS_LABELSENTRY, ],
  enum_types=[
    _OPERATIONPARAMS_OPERATIONMODE,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=231,
  serialized_end=669,
)


_GETOPERATIONREQUEST = _descriptor.Descriptor(
  name='GetOperationRequest',
  full_name='Ydb.Operations.GetOperationRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='id', full_name='Ydb.Operations.GetOperationRequest.id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\220\346*\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=671,
  serialized_end=710,
)


_GETOPERATIONRESPONSE = _descriptor.Descriptor(
  name='GetOperationResponse',
  full_name='Ydb.Operations.GetOperationResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='operation', full_name='Ydb.Operations.GetOperationResponse.operation', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=712,
  serialized_end=780,
)


_CANCELOPERATIONREQUEST = _descriptor.Descriptor(
  name='CancelOperationRequest',
  full_name='Ydb.Operations.CancelOperationRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='id', full_name='Ydb.Operations.CancelOperationRequest.id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\220\346*\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=782,
  serialized_end=824,
)


_CANCELOPERATIONRESPONSE = _descriptor.Descriptor(
  name='CancelOperationResponse',
  full_name='Ydb.Operations.CancelOperationResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='status', full_name='Ydb.Operations.CancelOperationResponse.status', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='issues', full_name='Ydb.Operations.CancelOperationResponse.issues', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=826,
  serialized_end=935,
)


_FORGETOPERATIONREQUEST = _descriptor.Descriptor(
  name='ForgetOperationRequest',
  full_name='Ydb.Operations.ForgetOperationRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='id', full_name='Ydb.Operations.ForgetOperationRequest.id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\220\346*\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=937,
  serialized_end=979,
)


_FORGETOPERATIONRESPONSE = _descriptor.Descriptor(
  name='ForgetOperationResponse',
  full_name='Ydb.Operations.ForgetOperationResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='status', full_name='Ydb.Operations.ForgetOperationResponse.status', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='issues', full_name='Ydb.Operations.ForgetOperationResponse.issues', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=981,
  serialized_end=1090,
)


_LISTOPERATIONSREQUEST = _descriptor.Descriptor(
  name='ListOperationsRequest',
  full_name='Ydb.Operations.ListOperationsRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='kind', full_name='Ydb.Operations.ListOperationsRequest.kind', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\220\346*\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='page_size', full_name='Ydb.Operations.ListOperationsRequest.page_size', index=1,
      number=2, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='page_token', full_name='Ydb.Operations.ListOperationsRequest.page_token', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1092,
  serialized_end=1174,
)


_LISTOPERATIONSRESPONSE = _descriptor.Descriptor(
  name='ListOperationsResponse',
  full_name='Ydb.Operations.ListOperationsResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='status', full_name='Ydb.Operations.ListOperationsResponse.status', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='issues', full_name='Ydb.Operations.ListOperationsResponse.issues', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='operations', full_name='Ydb.Operations.ListOperationsResponse.operations', index=2,
      number=3, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='next_page_token', full_name='Ydb.Operations.ListOperationsResponse.next_page_token', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1177,
  serialized_end=1357,
)


_OPERATION = _descriptor.Descriptor(
  name='Operation',
  full_name='Ydb.Operations.Operation',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='id', full_name='Ydb.Operations.Operation.id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='ready', full_name='Ydb.Operations.Operation.ready', index=1,
      number=2, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='status', full_name='Ydb.Operations.Operation.status', index=2,
      number=3, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='issues', full_name='Ydb.Operations.Operation.issues', index=3,
      number=4, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='result', full_name='Ydb.Operations.Operation.result', index=4,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='metadata', full_name='Ydb.Operations.Operation.metadata', index=5,
      number=6, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='cost_info', full_name='Ydb.Operations.Operation.cost_info', index=6,
      number=7, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1360,
  serialized_end=1594,
)

_OPERATIONPARAMS_LABELSENTRY.containing_type = _OPERATIONPARAMS
_OPERATIONPARAMS.fields_by_name['operation_mode'].enum_type = _OPERATIONPARAMS_OPERATIONMODE
_OPERATIONPARAMS.fields_by_name['operation_timeout'].message_type = google_dot_protobuf_dot_duration__pb2._DURATION
_OPERATIONPARAMS.fields_by_name['cancel_after'].message_type = google_dot_protobuf_dot_duration__pb2._DURATION
_OPERATIONPARAMS.fields_by_name['labels'].message_type = _OPERATIONPARAMS_LABELSENTRY
_OPERATIONPARAMS.fields_by_name['report_cost_info'].enum_type = protos_dot_ydb__common__pb2._FEATUREFLAG_STATUS
_OPERATIONPARAMS_OPERATIONMODE.containing_type = _OPERATIONPARAMS
_GETOPERATIONRESPONSE.fields_by_name['operation'].message_type = _OPERATION
_CANCELOPERATIONRESPONSE.fields_by_name['status'].enum_type = protos_dot_ydb__status__codes__pb2._STATUSIDS_STATUSCODE
_CANCELOPERATIONRESPONSE.fields_by_name['issues'].message_type = protos_dot_ydb__issue__message__pb2._ISSUEMESSAGE
_FORGETOPERATIONRESPONSE.fields_by_name['status'].enum_type = protos_dot_ydb__status__codes__pb2._STATUSIDS_STATUSCODE
_FORGETOPERATIONRESPONSE.fields_by_name['issues'].message_type = protos_dot_ydb__issue__message__pb2._ISSUEMESSAGE
_LISTOPERATIONSRESPONSE.fields_by_name['status'].enum_type = protos_dot_ydb__status__codes__pb2._STATUSIDS_STATUSCODE
_LISTOPERATIONSRESPONSE.fields_by_name['issues'].message_type = protos_dot_ydb__issue__message__pb2._ISSUEMESSAGE
_LISTOPERATIONSRESPONSE.fields_by_name['operations'].message_type = _OPERATION
_OPERATION.fields_by_name['status'].enum_type = protos_dot_ydb__status__codes__pb2._STATUSIDS_STATUSCODE
_OPERATION.fields_by_name['issues'].message_type = protos_dot_ydb__issue__message__pb2._ISSUEMESSAGE
_OPERATION.fields_by_name['result'].message_type = google_dot_protobuf_dot_any__pb2._ANY
_OPERATION.fields_by_name['metadata'].message_type = google_dot_protobuf_dot_any__pb2._ANY
_OPERATION.fields_by_name['cost_info'].message_type = protos_dot_ydb__common__pb2._COSTINFO
DESCRIPTOR.message_types_by_name['OperationParams'] = _OPERATIONPARAMS
DESCRIPTOR.message_types_by_name['GetOperationRequest'] = _GETOPERATIONREQUEST
DESCRIPTOR.message_types_by_name['GetOperationResponse'] = _GETOPERATIONRESPONSE
DESCRIPTOR.message_types_by_name['CancelOperationRequest'] = _CANCELOPERATIONREQUEST
DESCRIPTOR.message_types_by_name['CancelOperationResponse'] = _CANCELOPERATIONRESPONSE
DESCRIPTOR.message_types_by_name['ForgetOperationRequest'] = _FORGETOPERATIONREQUEST
DESCRIPTOR.message_types_by_name['ForgetOperationResponse'] = _FORGETOPERATIONRESPONSE
DESCRIPTOR.message_types_by_name['ListOperationsRequest'] = _LISTOPERATIONSREQUEST
DESCRIPTOR.message_types_by_name['ListOperationsResponse'] = _LISTOPERATIONSRESPONSE
DESCRIPTOR.message_types_by_name['Operation'] = _OPERATION
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

OperationParams = _reflection.GeneratedProtocolMessageType('OperationParams', (_message.Message,), {

  'LabelsEntry' : _reflection.GeneratedProtocolMessageType('LabelsEntry', (_message.Message,), {
    'DESCRIPTOR' : _OPERATIONPARAMS_LABELSENTRY,
    '__module__' : 'protos.ydb_operation_pb2'
    # @@protoc_insertion_point(class_scope:Ydb.Operations.OperationParams.LabelsEntry)
    })
  ,
  'DESCRIPTOR' : _OPERATIONPARAMS,
  '__module__' : 'protos.ydb_operation_pb2'
  # @@protoc_insertion_point(class_scope:Ydb.Operations.OperationParams)
  })
_sym_db.RegisterMessage(OperationParams)
_sym_db.RegisterMessage(OperationParams.LabelsEntry)

GetOperationRequest = _reflection.GeneratedProtocolMessageType('GetOperationRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETOPERATIONREQUEST,
  '__module__' : 'protos.ydb_operation_pb2'
  # @@protoc_insertion_point(class_scope:Ydb.Operations.GetOperationRequest)
  })
_sym_db.RegisterMessage(GetOperationRequest)

GetOperationResponse = _reflection.GeneratedProtocolMessageType('GetOperationResponse', (_message.Message,), {
  'DESCRIPTOR' : _GETOPERATIONRESPONSE,
  '__module__' : 'protos.ydb_operation_pb2'
  # @@protoc_insertion_point(class_scope:Ydb.Operations.GetOperationResponse)
  })
_sym_db.RegisterMessage(GetOperationResponse)

CancelOperationRequest = _reflection.GeneratedProtocolMessageType('CancelOperationRequest', (_message.Message,), {
  'DESCRIPTOR' : _CANCELOPERATIONREQUEST,
  '__module__' : 'protos.ydb_operation_pb2'
  # @@protoc_insertion_point(class_scope:Ydb.Operations.CancelOperationRequest)
  })
_sym_db.RegisterMessage(CancelOperationRequest)

CancelOperationResponse = _reflection.GeneratedProtocolMessageType('CancelOperationResponse', (_message.Message,), {
  'DESCRIPTOR' : _CANCELOPERATIONRESPONSE,
  '__module__' : 'protos.ydb_operation_pb2'
  # @@protoc_insertion_point(class_scope:Ydb.Operations.CancelOperationResponse)
  })
_sym_db.RegisterMessage(CancelOperationResponse)

ForgetOperationRequest = _reflection.GeneratedProtocolMessageType('ForgetOperationRequest', (_message.Message,), {
  'DESCRIPTOR' : _FORGETOPERATIONREQUEST,
  '__module__' : 'protos.ydb_operation_pb2'
  # @@protoc_insertion_point(class_scope:Ydb.Operations.ForgetOperationRequest)
  })
_sym_db.RegisterMessage(ForgetOperationRequest)

ForgetOperationResponse = _reflection.GeneratedProtocolMessageType('ForgetOperationResponse', (_message.Message,), {
  'DESCRIPTOR' : _FORGETOPERATIONRESPONSE,
  '__module__' : 'protos.ydb_operation_pb2'
  # @@protoc_insertion_point(class_scope:Ydb.Operations.ForgetOperationResponse)
  })
_sym_db.RegisterMessage(ForgetOperationResponse)

ListOperationsRequest = _reflection.GeneratedProtocolMessageType('ListOperationsRequest', (_message.Message,), {
  'DESCRIPTOR' : _LISTOPERATIONSREQUEST,
  '__module__' : 'protos.ydb_operation_pb2'
  # @@protoc_insertion_point(class_scope:Ydb.Operations.ListOperationsRequest)
  })
_sym_db.RegisterMessage(ListOperationsRequest)

ListOperationsResponse = _reflection.GeneratedProtocolMessageType('ListOperationsResponse', (_message.Message,), {
  'DESCRIPTOR' : _LISTOPERATIONSRESPONSE,
  '__module__' : 'protos.ydb_operation_pb2'
  # @@protoc_insertion_point(class_scope:Ydb.Operations.ListOperationsResponse)
  })
_sym_db.RegisterMessage(ListOperationsResponse)

Operation = _reflection.GeneratedProtocolMessageType('Operation', (_message.Message,), {
  'DESCRIPTOR' : _OPERATION,
  '__module__' : 'protos.ydb_operation_pb2'
  # @@protoc_insertion_point(class_scope:Ydb.Operations.Operation)
  })
_sym_db.RegisterMessage(Operation)


DESCRIPTOR._options = None
_OPERATIONPARAMS_LABELSENTRY._options = None
_OPERATIONPARAMS.fields_by_name['labels']._options = None
_GETOPERATIONREQUEST.fields_by_name['id']._options = None
_CANCELOPERATIONREQUEST.fields_by_name['id']._options = None
_FORGETOPERATIONREQUEST.fields_by_name['id']._options = None
_LISTOPERATIONSREQUEST.fields_by_name['kind']._options = None
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# flake8: noqa
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: protos/ydb_common.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor.FileDescriptor(
  name='protos/ydb_common.proto',
  package='Ydb',
  syntax='proto3',
  serialized_options=b'\n\017tech.ydb.commonB\014CommonProtosZ2github.com/ydb-platform/ydb-go-genproto/protos/Ydb\370\001\001',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n\x17protos/ydb_common.proto\x12\x03Ydb\"J\n\x0b\x46\x65\x61tureFlag\";\n\x06Status\x12\x16\n\x12STATUS_UNSPECIFIED\x10\x00\x12\x0b\n\x07\x45NABLED\x10\x01\x12\x0c\n\x08\x44ISABLED\x10\x02\"\"\n\x08\x43ostInfo\x12\x16\n\x0e\x63onsumed_units\x18\x01 \x01(\x01\"\x1d\n\rQuotaExceeded\x12\x0c\n\x04\x64isk\x18\x01 \x01(\x08\"4\n\x10VirtualTimestamp\x12\x11\n\tplan_step\x18\x01 \x01(\x04\x12\r\n\x05tx_id\x18\x02 \x01(\x04\x42V\n\x0ftech.ydb.commonB\x0c\x43ommonProtosZ2github.com/ydb-platform/ydb-go-genproto/protos/Ydb\xf8\x01\x01\x62\x06proto3'
)



_FEATUREFLAG_STATUS = _descriptor.EnumDescriptor(
  name='Status',
  full_name='Ydb.FeatureFlag.Status',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='STATUS_UNSPECIFIED', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='ENABLED', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='DISABLED', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=47,
  serialized_end=106,
)
_sym_db.RegisterEnumDescriptor(_FEATUREFLAG_STATUS)


_FEATUREFLAG = _descriptor.Descriptor(
  name='FeatureFlag',
  full_name='Ydb.FeatureFlag',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _FEATUREFLAG_STATUS,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=32,
  serialized_end=106,
)


_COSTINFO = _descriptor.Descriptor(
  name='CostInfo',
  full_name='Ydb.CostInfo',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='consumed_units', full_name='Ydb.CostInfo.consumed_units', index=0,
      number=1, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=108,
  serialized_end=142,
)


_QUOTAEXCEEDED = _descriptor.Descriptor(
  name='QuotaExceeded',
  full_name='Ydb.QuotaExceeded',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='disk', full_name='Ydb.QuotaExceeded.disk', index=0,
      number=1, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=144,
  serialized_end=173,
)


_VIRTUALTIMESTAMP = _descriptor.Descriptor(
  name='VirtualTimestamp',
  full_name='Ydb.VirtualTimestamp',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='plan_step', full_name='Ydb.VirtualTimestamp.plan_step', index=0,
      number=1, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='tx_id', full_name='Ydb.VirtualTimestamp.tx_id', index=1,
      number=2, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=175,
  serialized_end=227,
)

_FEATUREFLAG_STATUS.containing_type = _FEATUREFLAG
DESCRIPTOR.message_types_by_name['FeatureFlag'] = _FEATUREFLAG
DESCRIPTOR.message_types_by_name['CostInfo'] = _COSTINFO
DESCRIPTOR.message_types_by_name['QuotaExceeded'] = _QUOTAEXCEEDED
DESCRIPTOR.message_types_by_name['VirtualTimestamp'] = _VIRTUALTIMESTAMP
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

FeatureFlag = _reflection.GeneratedProtocolMessageType('FeatureFlag', (_message.Message,), {
  'DESCRIPTOR' : _FEATUREFLAG,
  '__module__' : 'protos.ydb_common_pb2'
  # @@protoc_insertion_point(class_scope:Ydb.FeatureFlag)
  })
_sym_db.RegisterMessage(FeatureFlag)

CostInfo = _reflection.GeneratedProtocolMessageType('CostInfo', (_message.Message,), {
  'DESCRIPTOR' : _COSTINFO,
  '__module__' : 'protos.ydb_common_pb2'
  # @@protoc_insertion_point(class_scope:Ydb.CostInfo)
  })
_sym_db.RegisterMessage(CostInfo)

QuotaExceeded = _reflection.GeneratedProtocolMessageType('QuotaExceeded', (_message.Message,), {
  'DESCRIPTOR' : _QUOTAEXCEEDED,
  '__module__' : 'protos.ydb_common_pb2'
  # @@protoc_insertion_point(class_scope:Ydb.QuotaExceeded)
  })
_sym_db.RegisterMessage(QuotaExceeded)

VirtualTimestamp = _reflection.GeneratedProtocolMessageType('VirtualTimestamp', (_message.Message,), {
  'DESCRIPTOR' : _VIRTUALTIMESTAMP,
  '__module__' : 'protos.ydb_common_pb2'
  # @@protoc_insertion_point(class_scope:Ydb.VirtualTimestamp)
  })
_sym_db.RegisterMessage(VirtualTimestamp)


DESCRIPTOR._options = None
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# flake8: noqa
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: ydb_operation_v1.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from ydb._grpc.v4.protos import ydb_operation_pb2 as protos_dot_ydb__operation__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x16ydb_operation_v1.proto\x12\x10Ydb.Operation.V1\x1a\x1aprotos/ydb_operation.proto2\x96\x03\n\x10OperationService\x12Y\n\x0cGetOperation\x12#.Ydb.Operations.GetOperationRequest\x1a$.Ydb.Operations.GetOperationResponse\x12\x62\n\x0f\x43\x61ncelOperation\x12&.Ydb.Operations.CancelOperationRequest\x1a\'.Ydb.Operations.CancelOperationResponse\x12\x62\n\x0f\x46orgetOperation\x12&.Ydb.Operations.ForgetOperationRequest\x1a\'.Ydb.Operations.ForgetOperationResponse\x12_\n\x0eListOperations\x12%.Ydb.Operations.ListOperationsRequest\x1a&.Ydb.Operations.ListOperationsResponseBQ\n\x15tech.ydb.operation.v1Z8github.com/ydb-platform/ydb-go-genproto/Ydb_Operation_V1b\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'ydb_operation_v1_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\025tech.ydb.operation.v1Z8github.com/ydb-platform/ydb-go-genproto/Ydb_Operation_V1'
  _OPERATIONSERVICE._serialized_start=73
  _OPERATIONSERVICE._serialized_end=479
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
import collections
from concurrent import futures
from six.moves import queue
import time
import threading
from . import settings, issues, _utilities, tracing


class SessionPoolImpl(object):
    def __init__(
        self,
        logger,
        driver,
        size,
        workers_threads_count=4,
        initializer=None,
        min_pool_size=0,
    ):
        self._lock = threading.RLock()
        self._waiters = collections.OrderedDict()
        self._driver = driver
        if hasattr(driver, "_driver_config"):
            self.tracer = driver._driver_config.tracer
        else:
            self.tracer = tracing.Tracer(None)
        self._active_queue = queue.PriorityQueue()
        self._active_count = 0
        self._size = size
        self._req_settings = settings.BaseRequestSettings().with_timeout(3)
        self._tp = futures.ThreadPoolExecutor(workers_threads_count)
        self._initializer = initializer
        self._should_stop = threading.Event()
        self._keep_alive_threshold = 4 * 60
        self._spin_timeout = 30
        self._event_queue = queue.Queue()
        self._driver_await_timeout = 3
        self._event_loop_thread = threading.Thread(target=self.events_loop)
        self._event_loop_thread.daemon = True
        self._event_loop_thread.start()
        self._logger = logger
        self._min_pool_size = min_pool_size
        self._terminating = False
        if self._min_pool_size > self._size:
            raise ValueError("Invalid min pool size value!")
        for _ in range(self._min_pool_size):
            self._prepare(self._create())

    def stop(self, timeout):
        with self._lock:
            self._logger.debug("Requested session pool stop.")
            self._event_queue.put(self._terminate_event)
            self._should_stop.set()
            self._terminating = True

            self._logger.debug(
                "Session pool is under stop, cancelling all in flight waiters."
            )
            while True:
                try:
                    _, waiter = self._waiters.popitem(last=False)
                    session = self._create()
                    waiter.set_result(session)
                    self._logger.debug(
                        "Waiter %s has been replied with empty session info. Session details: %s.",
                        waiter,
                        session,
                    )
                except KeyError:
                    break

            self._logger.debug("Destroying sessions in active queue")
            while True:
                try:
                    _, session = self._active_queue.get(block=False)
                    self._destroy(session, "session-pool-terminated")

                except queue.Empty:
                    break

            self._logger.debug("Destroyed active sessions")

        self._event_loop_thread.join(timeout)

    def _terminate_event(self):
        self._logger.debug("Terminated session pool.")
        raise StopIteration()

    def _delayed_prepare(self, session):
        try:
            self._driver.wait(self._driver_await_timeout, fail_fast=False)
        except Exception:
            pass

        self._prepare(session)

    def pick(self):
        with self._lock:
            try:
                priority, session = self._active_queue.get_nowait()
            except queue.Empty:
                return None

            till_expire = priority - time.time()
            if till_expire < self._keep_alive_threshold:
                return session
            self._active_queue.put((priority, session))
            return None

    def _create(self):
        with self._lock:
            session = self._driver.table_client.session()
            self._logger.debug("Created session %s", session)
            self._active_count += 1
            return session

    @property
    def active_size(self):
        with self._lock:
            return self._active_count

    @property
    def free_size(self):
        with self._lock:
            return self._active_queue.qsize()

    @property
    def busy_size(self):
        with self._lock:
            return self._active_count - self._active_queue.qsize()

    @property
    def max_size(self):
        return self._size

    @property
    def waiters_count(self):
        with self._lock:
            return len(self._waiters)

    def _is_min_pool_size_satisfied(self, delta=0):
        if self._terminating:
            return True
        return self._active_count + delta >= self._min_pool_size

    def _destroy(self, session, reason):
        self._logger.debug("Requested session destroy: %s, reason: %s", session, reason)
        with self._lock:
            tracing.trace(self.tracer, {"destroy.reason": reason})
            self._active_count -= 1
            self._logger.debug(
                "Session %s is no longer active. Current active count %d.",
                session,
                self._active_count,
            )
            cnt_waiters = len(self._waiters)
            if cnt_waiters > 0:
                self._logger.debug(
                    "In flight waiters: %d, preparing session %s replacement.",
                    cnt_waiters,
                    session,
                )
                # we have a waiter that should be replied, so we have to prepare replacement
                self._prepare(self._create())
            elif not self._is_min_pool_size_satisfied():
                self._logger.debug(
                    "Current session pool size is less than %s, actual size %s",
                    self._min_pool_size,
                    self._active_count,
                )
                self._prepare(self._create())

        if session.initialized():
            session.async_delete(self._req_settings)
            self._logger.debug("Sent delete on session %s", session)

    def put(self, session):
        with self._lock:
            self._logger.debug("Put on session %s", session)
            if session.closing():
                self._destroy(session, "session-close")
                return False

            if session.pending_query():
                self._destroy(session, "pending-query")
                return False

            if not session.initialized() or self._should_stop.is_set():
                self._destroy(session, "not-initialized")
                # we should probably prepare replacement session here
                return False

            try:
                _, waiter = self._waiters.popitem(last=False)
                waiter.set_result(session)
                tracing.trace(self.tracer, {"put.to_waiter": True})
                self._logger.debug("Replying to waiter with a session %s", session)
            except KeyError:
                priority = time.time() + 10 * 60
                tracing.trace(
                    self.tracer, {"put.to_pool": True, "session.new_priority": priority}
                )
                self._active_queue.put((priority, session))

    def _on_session_create(self, session, f):
        with self._lock:
            try:
                f.result()
                if self._initializer is None:
                    return self.put(session)
            except issues.Error as e:
                self._logger.error(
                    "Failed to create session. Put event to a delayed queue. Reason: %s",
                    str(e),
                )
                return self._event_queue.put(lambda: self._delayed_prepare(session))

            except Exception as e:
                self._logger.exception(
                    "Failed to create session. Put event to a delayed queue. Reason: %s",
                    str(e),
                )
                return self._event_queue.put(lambda: self._delayed_prepare(session))

        init_f = self._tp.submit(self._initializer, session)

        def _on_initialize(in_f):
            try:
                in_f.result()
                self.put(session)
            except Exception:
                self._prepare(session)

        init_f.add_done_callback(_on_initialize)

    def _prepare(self, session):
        if self._should_stop.is_set():
            self._destroy(session, "session-pool-terminated")
            return

        with self._lock:
            self._logger.debug("Preparing session %s", session)
            if len(self._waiters) < 1 and self._is_min_pool_size_satisfied(delta=-1):
                self._logger.info("No pending waiters, will destroy session")
                return self._destroy(session, "session-useless")

            f = session.async_create(self._req_settings)
            f.add_done_callback(lambda _: self._on_session_create(session, _))

    def _waiter_cleanup(self, w):
        with self._lock:
            try:
                self._waiters.pop(w)
            except KeyError:
                return None

    def subscribe(self):
        with self._lock:
            try:
                _, session = self._active_queue.get(block=False)
                tracing.trace(self.tracer, {"acquire.found_free_session": True})
                return _utilities.wrap_result_in_future(session)
            except queue.Empty:
                self._logger.debug(
                    "Active session queue is empty, subscribe waiter for a session"
                )
                waiter = _utilities.future()
                self._logger.debug("Subscribe waiter %s", waiter)
                if self._should_stop.is_set():
                    tracing.trace(
                        self.tracer,
                        {
                            "acquire.found_free_session": False,
                            "acquire.empty_session": True,
                        },
                    )
                    session = self._create()
                    self._logger.debug(
                        "Session pool is under stop, replying with empty session, %s",
                        session,
                    )
                    waiter.set_result(session)
                    return waiter

                waiter.add_done_callback(self._waiter_cleanup)
                self._waiters[waiter] = waiter
                if self._active_count < self._size:
                    self._logger.debug(
                        "Session pool is not large enough (active_count < size: %d < %d). "
                        "will create a new session.",
                        self._active_count,
                        self._size,
                    )
                    tracing.trace(
                        self.tracer,
                        {
                            "acquire.found_free_session": False,
                            "acquire.creating_new_session": True,
                            "session_pool.active_size": self._active_count,
                            "session_pool.size": self._size,
                        },
                    )
                    session = self._create()
                    self._prepare(session)
                else:
                    tracing.trace(
                        self.tracer,
                        {
                            "acquire.found_free_session": False,
                            "acquire.creating_new_session": False,
                            "session_pool.active_size": self._active_count,
                            "session_pool.size": self._size,
                            "acquire.waiting_for_free_session": True,
                        },
                    )
                return waiter

    def unsubscribe(self, waiter):
        with self._lock:
            try:
                # at first we remove waiter from list of the waiters to ensure
                # we will not signal it right now
                self._logger.debug("Unsubscribe on waiter %s", waiter)
                self._waiters.pop(waiter)
            except KeyError:
                try:
                    session = waiter.result(timeout=-1)
                    self.put(session)
                except (futures.CancelledError, futures.TimeoutError):
                    # future is cancelled and not signalled
                    pass

    def _on_keep_alive(self, session, f):
        try:
            self.put(f.result())
            # additional logic should be added to check
            # current status of the session
        except issues.Error:
            self._destroy(session, "keep-alive-error")
        except Exception:
            self._destroy(session, "keep-alive-error")

    def acquire(self, blocking=True, timeout=None):
        waiter = self.subscribe()
        has_result = False
        if blocking:
            tracing.trace(self.tracer, {"acquire.blocking": True})
            try:
                tracing.trace(self.tracer, {"acquire.blocking.wait": True})
                session = waiter.result(timeout=timeout)
                has_result = True
                return session
            except futures.TimeoutError:
                tracing.trace(self.tracer, {"acquire.blocking.timeout": True})
                raise issues.SessionPoolEmpty("Timeout on session acquire.")
            finally:
                if not has_result:
                    self.unsubscribe(waiter)

        else:
            tracing.trace(self.tracer, {"acquire.nonblocking": True})
            try:
                session = waiter.result(timeout=-1)
                has_result = True
                return session
            except futures.TimeoutError:
                raise issues.SessionPoolEmpty("Session pool is empty.")
            finally:
                if not has_result:
                    self.unsubscribe(waiter)

    def events_loop(self):
        while True:
            try:
                if self._should_stop.is_set():
                    break

                event = self._event_queue.get(timeout=self._spin_timeout)
                event()
            except StopIteration:
                break

            except queue.Empty:
                while True:
                    if not self.send_keep_alive():
                        break

    def send_keep_alive(self):
        session = self.pick()
        if session is None:
            return False

        if self._should_stop.is_set():
            self._destroy(session, "session-pool-terminated")
            return False

        f = session.async_keep_alive(self._req_settings)
        f.add_done_callback(lambda q: self._on_keep_alive(session, q))
        return True



# -*- coding: utf-8 -*-
# flake8: noqa
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: protos/ydb_table.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from ydb._grpc.v4.protos.annotations import validation_pb2 as protos_dot_annotations_dot_validation__pb2
from ydb._grpc.v4.protos import ydb_common_pb2 as protos_dot_ydb__common__pb2
from ydb._grpc.v4.protos import ydb_issue_message_pb2 as protos_dot_ydb__issue__message__pb2
from ydb._grpc.v4.protos import ydb_operation_pb2 as protos_dot_ydb__operation__pb2
from ydb._grpc.v4.protos import ydb_query_stats_pb2 as protos_dot_ydb__query__stats__pb2
from ydb._grpc.v4.protos import ydb_value_pb2 as protos_dot_ydb__value__pb2
from ydb._grpc.v4.protos import ydb_scheme_pb2 as protos_dot_ydb__scheme__pb2
from ydb._grpc.v4.protos import ydb_status_codes_pb2 as protos_dot_ydb__status__codes__pb2
from ydb._grpc.v4.protos import ydb_formats_pb2 as protos_dot_ydb__formats__pb2
from google.protobuf import empty_pb2 as google_dot_protobuf_dot_empty__pb2
from google.protobuf import duration_pb2 as google_dot_protobuf_dot_duration__pb2
from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x16protos/ydb_table.proto\x12\tYdb.Table\x1a#protos/annotations/validation.proto\x1a\x17protos/ydb_common.proto\x1a\x1eprotos/ydb_issue_message.proto\x1a\x1aprotos/ydb_operation.proto\x1a\x1cprotos/ydb_query_stats.proto\x1a\x16protos/ydb_value.proto\x1a\x17protos/ydb_scheme.proto\x1a\x1dprotos/ydb_status_codes.proto\x1a\x18protos/ydb_formats.proto\x1a\x1bgoogle/protobuf/empty.proto\x1a\x1egoogle/protobuf/duration.proto\x1a\x1fgoogle/protobuf/timestamp.proto\"Q\n\x14\x43reateSessionRequest\x12\x39\n\x10operation_params\x18\x01 \x01(\x0b\x32\x1f.Ydb.Operations.OperationParams\"E\n\x15\x43reateSessionResponse\x12,\n\toperation\x18\x01 \x01(\x0b\x32\x19.Ydb.Operations.Operation\")\n\x13\x43reateSessionResult\x12\x12\n\nsession_id\x18\x01 \x01(\t\"e\n\x14\x44\x65leteSessionRequest\x12\x12\n\nsession_id\x18\x01 \x01(\t\x12\x39\n\x10operation_params\x18\x02 \x01(\x0b\x32\x1f.Ydb.Operations.OperationParams\"E\n\x15\x44\x65leteSessionResponse\x12,\n\toperation\x18\x01 \x01(\x0b\x32\x19.Ydb.Operations.Operation\"\r\n\x0bGlobalIndex\"\x12\n\x10GlobalAsyncIndex\"\xba\x01\n\nTableIndex\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x15\n\rindex_columns\x18\x02 \x03(\t\x12.\n\x0cglobal_index\x18\x03 \x01(\x0b\x32\x16.Ydb.Table.GlobalIndexH\x00\x12\x39\n\x12global_async_index\x18\x04 \x01(\x0b\x32\x1b.Ydb.Table.GlobalAsyncIndexH\x00\x12\x14\n\x0c\x64\x61ta_columns\x18\x05 \x03(\tB\x06\n\x04type\"\xdb\x02\n\x15TableIndexDescription\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x15\n\rindex_columns\x18\x02 \x03(\t\x12.\n\x0cglobal_index\x18\x03 \x01(\x0b\x32\x16.Ydb.Table.GlobalIndexH\x00\x12\x39\n\x12global_async_index\x18\x05 \x01(\x0b\x32\x1b.Ydb.Table.GlobalAsyncIndexH\x00\x12\x37\n\x06status\x18\x04 \x01(\x0e\x32\'.Ydb.Table.TableIndexDescription.Status\x12\x14\n\x0c\x64\x61ta_columns\x18\x06 \x03(\t\x12\x12\n\nsize_bytes\x18\x07 \x01(\x04\"G\n\x06Status\x12\x16\n\x12STATUS_UNSPECIFIED\x10\x00\x12\x10\n\x0cSTATUS_READY\x10\x01\x12\x13\n\x0fSTATUS_BUILDING\x10\x02\x42\x06\n\x04type\"\xdd\x01\n\x0fIndexBuildState\"\xc9\x01\n\x05State\x12\x15\n\x11STATE_UNSPECIFIED\x10\x00\x12\x13\n\x0fSTATE_PREPARING\x10\x01\x12\x1a\n\x16STATE_TRANSFERING_DATA\x10\x02\x12\x12\n\x0eSTATE_APPLYING\x10\x03\x12\x0e\n\nSTATE_DONE\x10\x04\x12\x16\n\x12STATE_CANCELLATION\x10\x05\x12\x13\n\x0fSTATE_CANCELLED\x10\x06\x12\x13\n\x0fSTATE_REJECTION\x10\x07\x12\x12\n\x0eSTATE_REJECTED\x10\x08\"K\n\x15IndexBuildDescription\x12\x0c\n\x04path\x18\x01 \x01(\t\x12$\n\x05index\x18\x02 \x01(\x0b\x32\x15.Ydb.Table.TableIndex\"\x8e\x01\n\x12IndexBuildMetadata\x12\x35\n\x0b\x64\x65scription\x18\x01 \x01(\x0b\x32 .Ydb.Table.IndexBuildDescription\x12/\n\x05state\x18\x02 \x01(\x0e\x32 .Ydb.Table.IndexBuildState.State\x12\x10\n\x08progress\x18\x03 \x01(\x02\"\x9a\x01\n\x0e\x43hangefeedMode\"\x87\x01\n\x04Mode\x12\x14\n\x10MODE_UNSPECIFIED\x10\x00\x12\x12\n\x0eMODE_KEYS_ONLY\x10\x01\x12\x10\n\x0cMODE_UPDATES\x10\x02\x12\x12\n\x0eMODE_NEW_IMAGE\x10\x03\x12\x12\n\x0eMODE_OLD_IMAGE\x10\x04\x12\x1b\n\x17MODE_NEW_AND_OLD_IMAGES\x10\x05\"E\n\x10\x43hangefeedFormat\"1\n\x06\x46ormat\x12\x16\n\x12\x46ORMAT_UNSPECIFIED\x10\x00\x12\x0f\n\x0b\x46ORMAT_JSON\x10\x01\"\xcd\x01\n\nChangefeed\x12\x0c\n\x04name\x18\x01 \x01(\t\x12,\n\x04mode\x18\x02 \x01(\x0e\x32\x1e.Ydb.Table.ChangefeedMode.Mode\x12\x32\n\x06\x66ormat\x18\x03 \x01(\x0e\x32\".Ydb.Table.ChangefeedFormat.Format\x12\x33\n\x10retention_period\x18\x04 \x01(\x0b\x32\x19.google.protobuf.Duration\x12\x1a\n\x12virtual_timestamps\x18\x05 \x01(\x08\"\xa1\x02\n\x15\x43hangefeedDescription\x12\x0c\n\x04name\x18\x01 \x01(\t\x12,\n\x04mode\x18\x02 \x01(\x0e\x32\x1e.Ydb.Table.ChangefeedMode.Mode\x12\x32\n\x06\x66ormat\x18\x03 \x01(\x0e\x32\".Ydb.Table.ChangefeedFormat.Format\x12\x35\n\x05state\x18\x04 \x01(\x0e\x32&.Ydb.Table.ChangefeedDescription.State\x12\x1a\n\x12virtual_timestamps\x18\x05 \x01(\x08\"E\n\x05State\x12\x15\n\x11STATE_UNSPECIFIED\x10\x00\x12\x11\n\rSTATE_ENABLED\x10\x01\x12\x12\n\x0eSTATE_DISABLED\x10\x02\"\x1c\n\x0bStoragePool\x12\r\n\x05media\x18\x01 \x01(\t\"\xaa\x02\n\rStoragePolicy\x12\x13\n\x0bpreset_name\x18\x01 \x01(\t\x12&\n\x06syslog\x18\x02 \x01(\x0b\x32\x16.Ydb.Table.StoragePool\x12#\n\x03log\x18\x03 \x01(\x0b\x32\x16.Ydb.Table.StoragePool\x12$\n\x04\x64\x61ta\x18\x04 \x01(\x0b\x32\x16.Ydb.Table.StoragePool\x12(\n\x08\x65xternal\x18\x05 \x01(\x0b\x32\x16.Ydb.Table.StoragePool\x12/\n\x0ekeep_in_memory\x18\x06 \x01(\x0e\x32\x17.Ydb.FeatureFlag.Status\x12\x36\n\x0f\x63olumn_families\x18\x07 \x03(\x0b\x32\x1d.Ydb.Table.ColumnFamilyPolicy\"\xb1\x02\n\x12\x43olumnFamilyPolicy\x12\x0c\n\x04name\x18\x01 \x01(\t\x12$\n\x04\x64\x61ta\x18\x02 \x01(\x0b\x32\x16.Ydb.Table.StoragePool\x12(\n\x08\x65xternal\x18\x03 \x01(\x0b\x32\x16.Ydb.Table.StoragePool\x12/\n\x0ekeep_in_memory\x18\x04 \x01(\x0e\x32\x17.Ydb.FeatureFlag.Status\x12>\n\x0b\x63ompression\x18\x05 \x01(\x0e\x32).Ydb.Table.ColumnFamilyPolicy.Compression\"L\n\x0b\x43ompression\x12\x1b\n\x17\x43OMPRESSION_UNSPECIFIED\x10\x00\x12\x10\n\x0cUNCOMPRESSED\x10\x01\x12\x0e\n\nCOMPRESSED\x10\x02\"\'\n\x10\x43ompactionPolicy\x12\x13\n\x0bpreset_name\x18\x01 \x01(\t\";\n\x12\x45xplicitPartitions\x12%\n\x0csplit_points\x18\x01 \x03(\x0b\x32\x0f.Ydb.TypedValue\";\n\x0ePartitionStats\x12\x15\n\rrows_estimate\x18\x01 \x01(\x04\x12\x12\n\nstore_size\x18\x02 \x01(\x04\"\xe9\x01\n\nTableStats\x12\x32\n\x0fpartition_stats\x18\x01 \x03(\x0b\x32\x19.Ydb.Table.PartitionStats\x12\x15\n\rrows_estimate\x18\x02 \x01(\x04\x12\x12\n\nstore_size\x18\x03 \x01(\x04\x12\x12\n\npartitions\x18\x04 \x01(\x04\x12\x31\n\rcreation_time\x18\x05 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x35\n\x11modification_time\x18\x06 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\"\xdc\x02\n\x12PartitioningPolicy\x12\x13\n\x0bpreset_name\x18\x01 \x01(\t\x12O\n\x11\x61uto_partitioning\x18\x02 \x01(\x0e\x32\x34.Ydb.Table.PartitioningPolicy.AutoPartitioningPolicy\x12\x1c\n\x12uniform_partitions\x18\x03 \x01(\x04H\x00\x12<\n\x13\x65xplicit_partitions\x18\x04 \x01(\x0b\x32\x1d.Ydb.Table.ExplicitPartitionsH\x00\"v\n\x16\x41utoPartitioningPolicy\x12(\n$AUTO_PARTITIONING_POLICY_UNSPECIFIED\x10\x00\x12\x0c\n\x08\x44ISABLED\x10\x01\x12\x0e\n\nAUTO_SPLIT\x10\x02\x12\x14\n\x10\x41UTO_SPLIT_MERGE\x10\x03\x42\x0c\n\npartitions\"&\n\x0f\x45xecutionPolicy\x12\x13\n\x0bpreset_name\x18\x01 \x01(\t\"\xb1\x01\n\x11ReplicationPolicy\x12\x13\n\x0bpreset_name\x18\x01 \x01(\t\x12\x16\n\x0ereplicas_count\x18\x02 \x01(\r\x12=\n\x1c\x63reate_per_availability_zone\x18\x03 \x01(\x0e\x32\x17.Ydb.FeatureFlag.Status\x12\x30\n\x0f\x61llow_promotion\x18\x04 \x01(\x0e\x32\x17.Ydb.FeatureFlag.Status\"$\n\rCachingPolicy\x12\x13\n\x0bpreset_name\x18\x01 \x01(\t\"\xeb\x02\n\x0cTableProfile\x12\x13\n\x0bpreset_name\x18\x01 \x01(\t\x12\x30\n\x0estorage_policy\x18\x02 \x01(\x0b\x32\x18.Ydb.Table.StoragePolicy\x12\x36\n\x11\x63ompaction_policy\x18\x03 \x01(\x0b\x32\x1b.Ydb.Table.CompactionPolicy\x12:\n\x13partitioning_policy\x18\x04 \x01(\x0b\x32\x1d.Ydb.Table.PartitioningPolicy\x12\x34\n\x10\x65xecution_policy\x18\x05 \x01(\x0b\x32\x1a.Ydb.Table.ExecutionPolicy\x12\x38\n\x12replication_policy\x18\x06 \x01(\x0b\x32\x1c.Ydb.Table.ReplicationPolicy\x12\x30\n\x0e\x63\x61\x63hing_policy\x18\x07 \x01(\x0b\x32\x18.Ydb.Table.CachingPolicy\"C\n\nColumnMeta\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x17\n\x04type\x18\x02 \x01(\x0b\x32\t.Ydb.Type\x12\x0e\n\x06\x66\x61mily\x18\x03 \x01(\t\"O\n\x1a\x44\x61teTypeColumnModeSettings\x12\x13\n\x0b\x63olumn_name\x18\x01 \x01(\t\x12\x1c\n\x14\x65xpire_after_seconds\x18\x02 \x01(\r\"\x8e\x02\n\x1fValueSinceUnixEpochModeSettings\x12\x13\n\x0b\x63olumn_name\x18\x01 \x01(\t\x12\x44\n\x0b\x63olumn_unit\x18\x02 \x01(\x0e\x32/.Ydb.Table.ValueSinceUnixEpochModeSettings.Unit\x12\x1c\n\x14\x65xpire_after_seconds\x18\x03 \x01(\r\"r\n\x04Unit\x12\x14\n\x10UNIT_UNSPECIFIED\x10\x00\x12\x10\n\x0cUNIT_SECONDS\x10\x01\x12\x15\n\x11UNIT_MILLISECONDS\x10\x02\x12\x15\n\x11UNIT_MICROSECONDS\x10\x03\x12\x14\n\x10UNIT_NANOSECONDS\x10\x04\"\xc4\x01\n\x0bTtlSettings\x12\x41\n\x10\x64\x61te_type_column\x18\x01 \x01(\x0b\x32%.Ydb.Table.DateTypeColumnModeSettingsH\x00\x12L\n\x16value_since_unix_epoch\x18\x02 \x01(\x0b\x32*.Ydb.Table.ValueSinceUnixEpochModeSettingsH\x00\x12\x1c\n\x14run_interval_seconds\x18\x03 \x01(\rB\x06\n\x04mode\"\xda\x01\n\x0fStorageSettings\x12\x32\n\x12tablet_commit_log0\x18\x01 \x01(\x0b\x32\x16.Ydb.Table.StoragePool\x12\x32\n\x12tablet_commit_log1\x18\x02 \x01(\x0b\x32\x16.Ydb.Table.StoragePool\x12(\n\x08\x65xternal\x18\x04 \x01(\x0b\x32\x16.Ydb.Table.StoragePool\x12\x35\n\x14store_external_blobs\x18\x05 \x01(\x0e\x32\x17.Ydb.FeatureFlag.Status\"\x84\x02\n\x0c\x43olumnFamily\x12\x0c\n\x04name\x18\x01 \x01(\t\x12$\n\x04\x64\x61ta\x18\x02 \x01(\x0b\x32\x16.Ydb.Table.StoragePool\x12\x38\n\x0b\x63ompression\x18\x03 \x01(\x0e\x32#.Ydb.Table.ColumnFamily.Compression\x12/\n\x0ekeep_in_memory\x18\x04 \x01(\x0e\x32\x17.Ydb.FeatureFlag.Status\"U\n\x0b\x43ompression\x12\x1b\n\x17\x43OMPRESSION_UNSPECIFIED\x10\x00\x12\x14\n\x10\x43OMPRESSION_NONE\x10\x01\x12\x13\n\x0f\x43OMPRESSION_LZ4\x10\x02\"\xf7\x01\n\x14PartitioningSettings\x12\x14\n\x0cpartition_by\x18\x01 \x03(\t\x12\x35\n\x14partitioning_by_size\x18\x02 \x01(\x0e\x32\x17.Ydb.FeatureFlag.Status\x12\x19\n\x11partition_size_mb\x18\x03 \x01(\x04\x12\x35\n\x14partitioning_by_load\x18\x04 \x01(\x0e\x32\x17.Ydb.FeatureFlag.Status\x12\x1c\n\x14min_partitions_count\x18\x06 \x01(\x04\x12\x1c\n\x14max_partitions_count\x18\x07 \x01(\x04J\x04\x08\x05\x10\x06\"C\n\x16\x41zReadReplicasSettings\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x1b\n\x13read_replicas_count\x18\x02 \x01(\x04\"_\n\x17\x43lusterReplicasSettings\x12\x44\n\x19\x61z_read_replicas_settings\x18\x02 \x03(\x0b\x32!.Ydb.Table.AzReadReplicasSettings\"t\n\x14ReadReplicasSettings\x12$\n\x1aper_az_read_replicas_count\x18\x01 \x01(\x04H\x00\x12$\n\x1a\x61ny_az_read_replicas_count\x18\x02 \x01(\x04H\x00\x42\n\n\x08settingsJ\x04\x08\x03\x10\x04\"\xdc\x06\n\x12\x43reateTableRequest\x12\x12\n\nsession_id\x18\x01 \x01(\t\x12\x0c\n\x04path\x18\x02 \x01(\t\x12&\n\x07\x63olumns\x18\x03 \x03(\x0b\x32\x15.Ydb.Table.ColumnMeta\x12\x13\n\x0bprimary_key\x18\x04 \x03(\t\x12(\n\x07profile\x18\x05 \x01(\x0b\x32\x17.Ydb.Table.TableProfile\x12\x39\n\x10operation_params\x18\x06 \x01(\x0b\x32\x1f.Ydb.Operations.OperationParams\x12&\n\x07indexes\x18\x07 \x03(\x0b\x32\x15.Ydb.Table.TableIndex\x12,\n\x0cttl_settings\x18\x08 \x01(\x0b\x32\x16.Ydb.Table.TtlSettings\x12\x34\n\x10storage_settings\x18\t \x01(\x0b\x32\x1a.Ydb.Table.StorageSettings\x12\x30\n\x0f\x63olumn_families\x18\n \x03(\x0b\x32\x17.Ydb.Table.ColumnFamily\x12Z\n\nattributes\x18\x0b \x03(\x0b\x32-.Ydb.Table.CreateTableRequest.AttributesEntryB\x17\xaa\xe6*\x08\n\x06\n\x04\x08\x01\x10\x64\xa2\xe6*\x07\n\x05\x08\x01\x10\x80 \x12\x19\n\x11\x63ompaction_policy\x18\x0c \x01(\t\x12\x1c\n\x12uniform_partitions\x18\r \x01(\x04H\x00\x12:\n\x11partition_at_keys\x18\x0e \x01(\x0b\x32\x1d.Ydb.Table.ExplicitPartitionsH\x00\x12>\n\x15partitioning_settings\x18\x0f \x01(\x0b\x32\x1f.Ydb.Table.PartitioningSettings\x12\x31\n\x10key_bloom_filter\x18\x10 \x01(\x0e\x32\x17.Ydb.FeatureFlag.Status\x12?\n\x16read_replicas_settings\x18\x11 \x01(\x0b\x32\x1f.Ydb.Table.ReadReplicasSettings\x1a\x31\n\x0f\x41ttributesEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\x42\x0c\n\npartitions\"C\n\x13\x43reateTableResponse\x12,\n\toperation\x18\x01 \x01(\x0b\x32\x19.Ydb.Operations.Operation\"u\n\x10\x44ropTableRequest\x12\x12\n\nsession_id\x18\x01 \x01(\t\x12\x0c\n\x04path\x18\x02 \x01(\t\x12\x39\n\x10operation_params\x18\x04 \x01(\x0b\x32\x1f.Ydb.Operations.OperationParamsJ\x04\x08\x03\x10\x04\"A\n\x11\x44ropTableResponse\x12,\n\toperation\x18\x01 \x01(\x0b\x32\x19.Ydb.Operations.Operation\"]\n\x0fRenameIndexItem\x12\x13\n\x0bsource_name\x18\x01 \x01(\t\x12\x18\n\x10\x64\x65stination_name\x18\x02 \x01(\t\x12\x1b\n\x13replace_destination\x18\x03 \x01(\x08\"\xbc\x08\n\x11\x41lterTableRequest\x12\x12\n\nsession_id\x18\x01 \x01(\t\x12\x0c\n\x04path\x18\x02 \x01(\t\x12*\n\x0b\x61\x64\x64_columns\x18\x03 \x03(\x0b\x32\x15.Ydb.Table.ColumnMeta\x12\x14\n\x0c\x64rop_columns\x18\x04 \x03(\t\x12\x39\n\x10operation_params\x18\x05 \x01(\x0b\x32\x1f.Ydb.Operations.OperationParams\x12,\n\ralter_columns\x18\x06 \x03(\x0b\x32\x15.Ydb.Table.ColumnMeta\x12\x32\n\x10set_ttl_settings\x18\x07 \x01(\x0b\x32\x16.Ydb.Table.TtlSettingsH\x00\x12\x33\n\x11\x64rop_ttl_settings\x18\x08 \x01(\x0b\x32\x16.google.protobuf.EmptyH\x00\x12*\n\x0b\x61\x64\x64_indexes\x18\t \x03(\x0b\x32\x15.Ydb.Table.TableIndex\x12\x14\n\x0c\x64rop_indexes\x18\n \x03(\t\x12:\n\x16\x61lter_storage_settings\x18\x0b \x01(\x0b\x32\x1a.Ydb.Table.StorageSettings\x12\x34\n\x13\x61\x64\x64_column_families\x18\x0c \x03(\x0b\x32\x17.Ydb.Table.ColumnFamily\x12\x36\n\x15\x61lter_column_families\x18\r \x03(\x0b\x32\x17.Ydb.Table.ColumnFamily\x12`\n\x10\x61lter_attributes\x18\x0e \x03(\x0b\x32\x31.Ydb.Table.AlterTableRequest.AlterAttributesEntryB\x13\xaa\xe6*\x08\n\x06\n\x04\x08\x01\x10\x64\xa2\xe6*\x03\x18\x80 \x12\x1d\n\x15set_compaction_policy\x18\x0f \x01(\t\x12\x44\n\x1b\x61lter_partitioning_settings\x18\x10 \x01(\x0b\x32\x1f.Ydb.Table.PartitioningSettings\x12\x35\n\x14set_key_bloom_filter\x18\x11 \x01(\x0e\x32\x17.Ydb.FeatureFlag.Status\x12\x43\n\x1aset_read_replicas_settings\x18\x12 \x01(\x0b\x32\x1f.Ydb.Table.ReadReplicasSettings\x12.\n\x0f\x61\x64\x64_changefeeds\x18\x13 \x03(\x0b\x32\x15.Ydb.Table.Changefeed\x12\x18\n\x10\x64rop_changefeeds\x18\x14 \x03(\t\x12\x32\n\x0erename_indexes\x18\x15 \x03(\x0b\x32\x1a.Ydb.Table.RenameIndexItem\x1a\x36\n\x14\x41lterAttributesEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\x42\x0c\n\nttl_action\"B\n\x12\x41lterTableResponse\x12,\n\toperation\x18\x01 \x01(\x0b\x32\x19.Ydb.Operations.Operation\"\x90\x01\n\x10\x43opyTableRequest\x12\x12\n\nsession_id\x18\x01 \x01(\t\x12\x13\n\x0bsource_path\x18\x02 \x01(\t\x12\x18\n\x10\x64\x65stination_path\x18\x03 \x01(\t\x12\x39\n\x10operation_params\x18\x04 \x01(\x0b\x32\x1f.Ydb.Operations.OperationParams\"A\n\x11\x43opyTableResponse\x12,\n\toperation\x18\x01 \x01(\x0b\x32\x19.Ydb.Operations.Operation\"T\n\rCopyTableItem\x12\x13\n\x0bsource_path\x18\x01 \x01(\t\x12\x18\n\x10\x64\x65stination_path\x18\x02 \x01(\t\x12\x14\n\x0comit_indexes\x18\x03 \x01(\x08\"\x8c\x01\n\x11\x43opyTablesRequest\x12\x39\n\x10operation_params\x18\x01 \x01(\x0b\x32\x1f.Ydb.Operations.OperationParams\x12\x12\n\nsession_id\x18\x02 \x01(\t\x12(\n\x06tables\x18\x03 \x03(\x0b\x32\x18.Ydb.Table.CopyTableItem\"B\n\x12\x43opyTablesResponse\x12,\n\toperation\x18\x01 \x01(\x0b\x32\x19.Ydb.Operations.Operation\"]\n\x0fRenameTableItem\x12\x13\n\x0bsource_path\x18\x01 \x01(\t\x12\x18\n\x10\x64\x65stination_path\x18\x02 \x01(\t\x12\x1b\n\x13replace_destination\x18\x03 \x01(\x08\"\x90\x01\n\x13RenameTablesRequest\x12\x39\n\x10operation_params\x18\x01 \x01(\x0b\x32\x1f.Ydb.Operations.OperationParams\x12\x12\n\nsession_id\x18\x02 \x01(\t\x12*\n\x06tables\x18\x03 \x03(\x0b\x32\x1a.Ydb.Table.RenameTableItem\"D\n\x14RenameTablesResponse\x12,\n\toperation\x18\x01 \x01(\x0b\x32\x19.Ydb.Operations.Operation\"\xd3\x01\n\x14\x44\x65scribeTableRequest\x12\x12\n\nsession_id\x18\x01 \x01(\t\x12\x0c\n\x04path\x18\x02 \x01(\t\x12\x39\n\x10operation_params\x18\x04 \x01(\x0b\x32\x1f.Ydb.Operations.OperationParams\x12 \n\x18include_shard_key_bounds\x18\x05 \x01(\x08\x12\x1b\n\x13include_table_stats\x18\x06 \x01(\x08\x12\x1f\n\x17include_partition_stats\x18\x07 \x01(\x08\"E\n\x15\x44\x65scribeTableResponse\x12,\n\toperation\x18\x01 \x01(\x0b\x32\x19.Ydb.Operations.Operation\"\xfb\x05\n\x13\x44\x65scribeTableResult\x12\x1f\n\x04self\x18\x01 \x01(\x0b\x32\x11.Ydb.Scheme.Entry\x12&\n\x07\x63olumns\x18\x02 \x03(\x0b\x32\x15.Ydb.Table.ColumnMeta\x12\x13\n\x0bprimary_key\x18\x03 \x03(\t\x12)\n\x10shard_key_bounds\x18\x04 \x03(\x0b\x32\x0f.Ydb.TypedValue\x12\x31\n\x07indexes\x18\x05 \x03(\x0b\x32 .Ydb.Table.TableIndexDescription\x12*\n\x0btable_stats\x18\x06 \x01(\x0b\x32\x15.Ydb.Table.TableStats\x12,\n\x0cttl_settings\x18\x07 \x01(\x0b\x32\x16.Ydb.Table.TtlSettings\x12\x34\n\x10storage_settings\x18\x08 \x01(\x0b\x32\x1a.Ydb.Table.StorageSettings\x12\x30\n\x0f\x63olumn_families\x18\t \x03(\x0b\x32\x17.Ydb.Table.ColumnFamily\x12\x42\n\nattributes\x18\n \x03(\x0b\x32..Ydb.Table.DescribeTableResult.AttributesEntry\x12>\n\x15partitioning_settings\x18\x0c \x01(\x0b\x32\x1f.Ydb.Table.PartitioningSettings\x12\x31\n\x10key_bloom_filter\x18\r \x01(\x0e\x32\x17.Ydb.FeatureFlag.Status\x12?\n\x16read_replicas_settings\x18\x0e \x01(\x0b\x32\x1f.Ydb.Table.ReadReplicasSettings\x12\x35\n\x0b\x63hangefeeds\x18\x0f \x03(\x0b\x32 .Ydb.Table.ChangefeedDescription\x1a\x31\n\x0f\x41ttributesEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01J\x04\x08\x0b\x10\x0c\"2\n\x05Query\x12\x12\n\x08yql_text\x18\x01 \x01(\tH\x00\x12\x0c\n\x02id\x18\x02 \x01(\tH\x00\x42\x07\n\x05query\"\x1a\n\x18SerializableModeSettings\"6\n\x12OnlineModeSettings\x12 \n\x18\x61llow_inconsistent_reads\x18\x01 \x01(\x08\"\x13\n\x11StaleModeSettings\"\x16\n\x14SnapshotModeSettings\"\x9b\x02\n\x13TransactionSettings\x12\x46\n\x17serializable_read_write\x18\x01 \x01(\x0b\x32#.Ydb.Table.SerializableModeSettingsH\x00\x12\x39\n\x10online_read_only\x18\x02 \x01(\x0b\x32\x1d.Ydb.Table.OnlineModeSettingsH\x00\x12\x37\n\x0fstale_read_only\x18\x03 \x01(\x0b\x32\x1c.Ydb.Table.StaleModeSettingsH\x00\x12=\n\x12snapshot_read_only\x18\x04 \x01(\x0b\x32\x1f.Ydb.Table.SnapshotModeSettingsH\x00\x42\t\n\x07tx_mode\"{\n\x12TransactionControl\x12\x0f\n\x05tx_id\x18\x01 \x01(\tH\x00\x12\x32\n\x08\x62\x65gin_tx\x18\x02 \x01(\x0b\x32\x1e.Ydb.Table.TransactionSettingsH\x00\x12\x11\n\tcommit_tx\x18\n \x01(\x08\x42\r\n\x0btx_selector\")\n\x10QueryCachePolicy\x12\x15\n\rkeep_in_cache\x18\x01 \x01(\x08\"\xb1\x01\n\x14QueryStatsCollection\"\x98\x01\n\x04Mode\x12 \n\x1cSTATS_COLLECTION_UNSPECIFIED\x10\x00\x12\x19\n\x15STATS_COLLECTION_NONE\x10\x01\x12\x1a\n\x16STATS_COLLECTION_BASIC\x10\x02\x12\x19\n\x15STATS_COLLECTION_FULL\x10\x03\x12\x1c\n\x18STATS_COLLECTION_PROFILE\x10\x04\"\xbe\x03\n\x17\x45xecuteDataQueryRequest\x12\x12\n\nsession_id\x18\x01 \x01(\t\x12\x31\n\ntx_control\x18\x02 \x01(\x0b\x32\x1d.Ydb.Table.TransactionControl\x12\x1f\n\x05query\x18\x03 \x01(\x0b\x32\x10.Ydb.Table.Query\x12\x46\n\nparameters\x18\x04 \x03(\x0b\x32\x32.Ydb.Table.ExecuteDataQueryRequest.ParametersEntry\x12\x37\n\x12query_cache_policy\x18\x05 \x01(\x0b\x32\x1b.Ydb.Table.QueryCachePolicy\x12\x39\n\x10operation_params\x18\x06 \x01(\x0b\x32\x1f.Ydb.Operations.OperationParams\x12;\n\rcollect_stats\x18\x07 \x01(\x0e\x32$.Ydb.Table.QueryStatsCollection.Mode\x1a\x42\n\x0fParametersEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\x1e\n\x05value\x18\x02 \x01(\x0b\x32\x0f.Ydb.TypedValue:\x02\x38\x01\"H\n\x18\x45xecuteDataQueryResponse\x12,\n\toperation\x18\x01 \x01(\x0b\x32\x19.Ydb.Operations.Operation\"|\n\x19\x45xecuteSchemeQueryRequest\x12\x12\n\nsession_id\x18\x01 \x01(\t\x12\x10\n\x08yql_text\x18\x02 \x01(\t\x12\x39\n\x10operation_params\x18\x03 \x01(\x0b\x32\x1f.Ydb.Operations.OperationParams\"J\n\x1a\x45xecuteSchemeQueryResponse\x12,\n\toperation\x18\x01 \x01(\x0b\x32\x19.Ydb.Operations.Operation\"\x1d\n\x0fTransactionMeta\x12\n\n\x02id\x18\x01 \x01(\t\"\x9f\x01\n\tQueryMeta\x12\n\n\x02id\x18\x01 \x01(\t\x12\x43\n\x10parameters_types\x18\x02 \x03(\x0b\x32).Ydb.Table.QueryMeta.ParametersTypesEntry\x1a\x41\n\x14ParametersTypesEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\x18\n\x05value\x18\x02 \x01(\x0b\x32\t.Ydb.Type:\x02\x38\x01\"\xc1\x01\n\x12\x45xecuteQueryResult\x12#\n\x0bresult_sets\x18\x01 \x03(\x0b\x32\x0e.Ydb.ResultSet\x12+\n\x07tx_meta\x18\x02 \x01(\x0b\x32\x1a.Ydb.Table.TransactionMeta\x12(\n\nquery_meta\x18\x03 \x01(\x0b\x32\x14.Ydb.Table.QueryMeta\x12/\n\x0bquery_stats\x18\x04 \x01(\x0b\x32\x1a.Ydb.TableStats.QueryStats\"z\n\x17\x45xplainDataQueryRequest\x12\x12\n\nsession_id\x18\x01 \x01(\t\x12\x10\n\x08yql_text\x18\x02 \x01(\t\x12\x39\n\x10operation_params\x18\x03 \x01(\x0b\x32\x1f.Ydb.Operations.OperationParams\"H\n\x18\x45xplainDataQueryResponse\x12,\n\toperation\x18\x01 \x01(\x0b\x32\x19.Ydb.Operations.Operation\";\n\x12\x45xplainQueryResult\x12\x11\n\tquery_ast\x18\x01 \x01(\t\x12\x12\n\nquery_plan\x18\x02 \x01(\t\"z\n\x17PrepareDataQueryRequest\x12\x12\n\nsession_id\x18\x01 \x01(\t\x12\x10\n\x08yql_text\x18\x02 \x01(\t\x12\x39\n\x10operation_params\x18\x03 \x01(\x0b\x32\x1f.Ydb.Operations.OperationParams\"H\n\x18PrepareDataQueryResponse\x12,\n\toperation\x18\x01 \x01(\x0b\x32\x19.Ydb.Operations.Operation\"\xb7\x01\n\x12PrepareQueryResult\x12\x10\n\x08query_id\x18\x01 \x01(\t\x12L\n\x10parameters_types\x18\x02 \x03(\x0b\x32\x32.Ydb.Table.PrepareQueryResult.ParametersTypesEntry\x1a\x41\n\x14ParametersTypesEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\x18\n\x05value\x18\x02 \x01(\x0b\x32\t.Ydb.Type:\x02\x38\x01\"a\n\x10KeepAliveRequest\x12\x12\n\nsession_id\x18\x01 \x01(\t\x12\x39\n\x10operation_params\x18\x02 \x01(\x0b\x32\x1f.Ydb.Operations.OperationParams\"A\n\x11KeepAliveResponse\x12,\n\toperation\x18\x01 \x01(\x0b\x32\x19.Ydb.Operations.Operation\"\xb7\x01\n\x0fKeepAliveResult\x12@\n\x0esession_status\x18\x01 \x01(\x0e\x32(.Ydb.Table.KeepAliveResult.SessionStatus\"b\n\rSessionStatus\x12\x1e\n\x1aSESSION_STATUS_UNSPECIFIED\x10\x00\x12\x18\n\x14SESSION_STATUS_READY\x10\x01\x12\x17\n\x13SESSION_STATUS_BUSY\x10\x02\"\x9d\x01\n\x17\x42\x65ginTransactionRequest\x12\x12\n\nsession_id\x18\x01 \x01(\t\x12\x33\n\x0btx_settings\x18\x02 \x01(\x0b\x32\x1e.Ydb.Table.TransactionSettings\x12\x39\n\x10operation_params\x18\x03 \x01(\x0b\x32\x1f.Ydb.Operations.OperationParams\"H\n\x18\x42\x65ginTransactionResponse\x12,\n\toperation\x18\x01 \x01(\x0b\x32\x19.Ydb.Operations.Operation\"E\n\x16\x42\x65ginTransactionResult\x12+\n\x07tx_meta\x18\x01 \x01(\x0b\x32\x1a.Ydb.Table.TransactionMeta\"\xb5\x01\n\x18\x43ommitTransactionRequest\x12\x12\n\nsession_id\x18\x01 \x01(\t\x12\r\n\x05tx_id\x18\x02 \x01(\t\x12\x39\n\x10operation_params\x18\x03 \x01(\x0b\x32\x1f.Ydb.Operations.OperationParams\x12;\n\rcollect_stats\x18\x04 \x01(\x0e\x32$.Ydb.Table.QueryStatsCollection.Mode\"I\n\x19\x43ommitTransactionResponse\x12,\n\toperation\x18\x01 \x01(\x0b\x32\x19.Ydb.Operations.Operation\"J\n\x17\x43ommitTransactionResult\x12/\n\x0bquery_stats\x18\x01 \x01(\x0b\x32\x1a.Ydb.TableStats.QueryStats\"z\n\x1aRollbackTransactionRequest\x12\x12\n\nsession_id\x18\x01 \x01(\t\x12\r\n\x05tx_id\x18\x02 \x01(\t\x12\x39\n\x10operation_params\x18\x03 \x01(\x0b\x32\x1f.Ydb.Operations.OperationParams\"K\n\x1bRollbackTransactionResponse\x12,\n\toperation\x18\x01 \x01(\x0b\x32\x19.Ydb.Operations.Operation\"\x98\x01\n\x18StoragePolicyDescription\x12\x0c\n\x04name\x18\x01 \x01(\t\x12?\n\x06labels\x18\x02 \x03(\x0b\x32/.Ydb.Table.StoragePolicyDescription.LabelsEntry\x1a-\n\x0bLabelsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"\x9e\x01\n\x1b\x43ompactionPolicyDescription\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x42\n\x06labels\x18\x02 \x03(\x0b\x32\x32.Ydb.Table.CompactionPolicyDescription.LabelsEntry\x1a-\n\x0bLabelsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"\xa2\x01\n\x1dPartitioningPolicyDescription\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x44\n\x06labels\x18\x02 \x03(\x0b\x32\x34.Ydb.Table.PartitioningPolicyDescription.LabelsEntry\x1a-\n\x0bLabelsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"\x9c\x01\n\x1a\x45xecutionPolicyDescription\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x41\n\x06labels\x18\x02 \x03(\x0b\x32\x31.Ydb.Table.ExecutionPolicyDescription.LabelsEntry\x1a-\n\x0bLabelsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"\xa0\x01\n\x1cReplicationPolicyDescription\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x43\n\x06labels\x18\x02 \x03(\x0b\x32\x33.Ydb.Table.ReplicationPolicyDescription.LabelsEntry\x1a-\n\x0bLabelsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"\x98\x01\n\x18\x43\x61\x63hingPolicyDescription\x12\x0c\n\x04name\x18\x01 \x01(\t\x12?\n\x06labels\x18\x02 \x03(\x0b\x32/.Ydb.Table.CachingPolicyDescription.LabelsEntry\x1a-\n\x0bLabelsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"\xbe\x04\n\x17TableProfileDescription\x12\x0c\n\x04name\x18\x01 \x01(\t\x12>\n\x06labels\x18\x02 \x03(\x0b\x32..Ydb.Table.TableProfileDescription.LabelsEntry\x12\x1e\n\x16\x64\x65\x66\x61ult_storage_policy\x18\x03 \x01(\t\x12 \n\x18\x61llowed_storage_policies\x18\x04 \x03(\t\x12!\n\x19\x64\x65\x66\x61ult_compaction_policy\x18\x05 \x01(\t\x12#\n\x1b\x61llowed_compaction_policies\x18\x06 \x03(\t\x12#\n\x1b\x64\x65\x66\x61ult_partitioning_policy\x18\x07 \x01(\t\x12%\n\x1d\x61llowed_partitioning_policies\x18\x08 \x03(\t\x12 \n\x18\x64\x65\x66\x61ult_execution_policy\x18\t \x01(\t\x12\"\n\x1a\x61llowed_execution_policies\x18\n \x03(\t\x12\"\n\x1a\x64\x65\x66\x61ult_replication_policy\x18\x0b \x01(\t\x12$\n\x1c\x61llowed_replication_policies\x18\x0c \x03(\t\x12\x1e\n\x16\x64\x65\x66\x61ult_caching_policy\x18\r \x01(\t\x12 \n\x18\x61llowed_caching_policies\x18\x0e \x03(\t\x1a-\n\x0bLabelsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"X\n\x1b\x44\x65scribeTableOptionsRequest\x12\x39\n\x10operation_params\x18\x01 \x01(\x0b\x32\x1f.Ydb.Operations.OperationParams\"L\n\x1c\x44\x65scribeTableOptionsResponse\x12,\n\toperation\x18\x01 \x01(\x0b\x32\x19.Ydb.Operations.Operation\"\x99\x04\n\x1a\x44\x65scribeTableOptionsResult\x12\x41\n\x15table_profile_presets\x18\x01 \x03(\x0b\x32\".Ydb.Table.TableProfileDescription\x12\x43\n\x16storage_policy_presets\x18\x02 \x03(\x0b\x32#.Ydb.Table.StoragePolicyDescription\x12I\n\x19\x63ompaction_policy_presets\x18\x03 \x03(\x0b\x32&.Ydb.Table.CompactionPolicyDescription\x12M\n\x1bpartitioning_policy_presets\x18\x04 \x03(\x0b\x32(.Ydb.Table.PartitioningPolicyDescription\x12G\n\x18\x65xecution_policy_presets\x18\x05 \x03(\x0b\x32%.Ydb.Table.ExecutionPolicyDescription\x12K\n\x1areplication_policy_presets\x18\x06 \x03(\x0b\x32\'.Ydb.Table.ReplicationPolicyDescription\x12\x43\n\x16\x63\x61\x63hing_policy_presets\x18\x07 \x03(\x0b\x32#.Ydb.Table.CachingPolicyDescription\"\xc0\x01\n\x08KeyRange\x12\"\n\x07greater\x18\x01 \x01(\x0b\x32\x0f.Ydb.TypedValueH\x00\x12+\n\x10greater_or_equal\x18\x02 \x01(\x0b\x32\x0f.Ydb.TypedValueH\x00\x12\x1f\n\x04less\x18\x03 \x01(\x0b\x32\x0f.Ydb.TypedValueH\x01\x12(\n\rless_or_equal\x18\x04 \x01(\x0b\x32\x0f.Ydb.TypedValueH\x01\x42\x0c\n\nfrom_boundB\n\n\x08to_bound\"\xc0\x01\n\x10ReadTableRequest\x12\x12\n\nsession_id\x18\x01 \x01(\t\x12\x0c\n\x04path\x18\x02 \x01(\t\x12&\n\tkey_range\x18\x03 \x01(\x0b\x32\x13.Ydb.Table.KeyRange\x12\x0f\n\x07\x63olumns\x18\x04 \x03(\t\x12\x0f\n\x07ordered\x18\x05 \x01(\x08\x12\x11\n\trow_limit\x18\x06 \x01(\x04\x12-\n\x0cuse_snapshot\x18\x07 \x01(\x0e\x32\x17.Ydb.FeatureFlag.Status\"\xbc\x01\n\x11ReadTableResponse\x12)\n\x06status\x18\x01 \x01(\x0e\x32\x19.Ydb.StatusIds.StatusCode\x12\'\n\x06issues\x18\x02 \x03(\x0b\x32\x17.Ydb.Issue.IssueMessage\x12\'\n\x08snapshot\x18\x04 \x01(\x0b\x32\x15.Ydb.VirtualTimestamp\x12*\n\x06result\x18\x03 \x01(\x0b\x32\x1a.Ydb.Table.ReadTableResult\"5\n\x0fReadTableResult\x12\"\n\nresult_set\x18\x01 \x01(\x0b\x32\x0e.Ydb.ResultSet\"\x8d\x02\n\x11\x42ulkUpsertRequest\x12\r\n\x05table\x18\x01 \x01(\t\x12\x1d\n\x04rows\x18\x02 \x01(\x0b\x32\x0f.Ydb.TypedValue\x12\x39\n\x10operation_params\x18\x03 \x01(\x0b\x32\x1f.Ydb.Operations.OperationParams\x12?\n\x14\x61rrow_batch_settings\x18\x07 \x01(\x0b\x32\x1f.Ydb.Formats.ArrowBatchSettingsH\x00\x12\x30\n\x0c\x63sv_settings\x18\x08 \x01(\x0b\x32\x18.Ydb.Formats.CsvSettingsH\x00\x12\r\n\x04\x64\x61ta\x18\xe8\x07 \x01(\x0c\x42\r\n\x0b\x64\x61ta_format\"B\n\x12\x42ulkUpsertResponse\x12,\n\toperation\x18\x01 \x01(\x0b\x32\x19.Ydb.Operations.Operation\"\x12\n\x10\x42ulkUpsertResult\"\x91\x03\n\x17\x45xecuteScanQueryRequest\x12\x1f\n\x05query\x18\x03 \x01(\x0b\x32\x10.Ydb.Table.Query\x12\x46\n\nparameters\x18\x04 \x03(\x0b\x32\x32.Ydb.Table.ExecuteScanQueryRequest.ParametersEntry\x12\x35\n\x04mode\x18\x06 \x01(\x0e\x32\'.Ydb.Table.ExecuteScanQueryRequest.Mode\x12;\n\rcollect_stats\x18\x08 \x01(\x0e\x32$.Ydb.Table.QueryStatsCollection.Mode\x1a\x42\n\x0fParametersEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\x1e\n\x05value\x18\x02 \x01(\x0b\x32\x0f.Ydb.TypedValue:\x02\x38\x01\"=\n\x04Mode\x12\x14\n\x10MODE_UNSPECIFIED\x10\x00\x12\x10\n\x0cMODE_EXPLAIN\x10\x01\x12\r\n\tMODE_EXEC\x10\x03J\x04\x08\x01\x10\x02J\x04\x08\x02\x10\x03J\x04\x08\x05\x10\x06J\x04\x08\x07\x10\x08\"\xaf\x01\n\x1f\x45xecuteScanQueryPartialResponse\x12)\n\x06status\x18\x01 \x01(\x0e\x32\x19.Ydb.StatusIds.StatusCode\x12\'\n\x06issues\x18\x02 \x03(\x0b\x32\x17.Ydb.Issue.IssueMessage\x12\x38\n\x06result\x18\x03 \x01(\x0b\x32(.Ydb.Table.ExecuteScanQueryPartialResult\"\x8c\x01\n\x1d\x45xecuteScanQueryPartialResult\x12\"\n\nresult_set\x18\x01 \x01(\x0b\x32\x0e.Ydb.ResultSet\x12/\n\x0bquery_stats\x18\x06 \x01(\x0b\x32\x1a.Ydb.TableStats.QueryStatsJ\x04\x08\x02\x10\x03J\x04\x08\x03\x10\x04J\x04\x08\x04\x10\x05J\x04\x08\x05\x10\x06\x42M\n\x0etech.ydb.tableZ8github.com/ydb-platform/ydb-go-genproto/protos/Ydb_Table\xf8\x01\x01\x62\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'protos.ydb_table_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\016tech.ydb.tableZ8github.com/ydb-platform/ydb-go-genproto/protos/Ydb_Table\370\001\001'
  _CREATETABLEREQUEST_ATTRIBUTESENTRY._options = None
  _CREATETABLEREQUEST_ATTRIBUTESENTRY._serialized_options = b'8\001'
  _CREATETABLEREQUEST.fields_by_name['attributes']._options = None
  _CREATETABLEREQUEST.fields_by_name['attributes']._serialized_options = b'\252\346*\010\n\006\n\004\010\001\020d\242\346*\007\n\005\010\001\020\200 '
  _ALTERTABLEREQUEST_ALTERATTRIBUTESENTRY._options = None
  _ALTERTABLEREQUEST_ALTERATTRIBUTESENTRY._serialized_options = b'8\001'
  _ALTERTABLEREQUEST.fields_by_name['alter_attributes']._options = None
  _ALTERTABLEREQUEST.fields_by_name['alter_attributes']._serialized_options = b'\252\346*\010\n\006\n\004\010\001\020d\242\346*\003\030\200 '
  _DESCRIBETABLERESULT_ATTRIBUTESENTRY._options = None
  _DESCRIBETABLERESULT_ATTRIBUTESENTRY._serialized_options = b'8\001'
  _EXECUTEDATAQUERYREQUEST_PARAMETERSENTRY._options = None
  _EXECUTEDATAQUERYREQUEST_PARAMETERSENTRY._serialized_options = b'8\001'
  _QUERYMETA_PARAMETERSTYPESENTRY._options = None
  _QUERYMETA_PARAMETERSTYPESENTRY._serialized_options = b'8\001'
  _PREPAREQUERYRESULT_PARAMETERSTYPESENTRY._options = None
  _PREPAREQUERYRESULT_PARAMETERSTYPESENTRY._serialized_options = b'8\001'
  _STORAGEPOLICYDESCRIPTION_LABELSENTRY._options = None
  _STORAGEPOLICYDESCRIPTION_LABELSENTRY._serialized_options = b'8\001'
  _COMPACTIONPOLICYDESCRIPTION_LABELSENTRY._options = None
  _COMPACTIONPOLICYDESCRIPTION_LABELSENTRY._serialized_options = b'8\001'
  _PARTITIONINGPOLICYDESCRIPTION_LABELSENTRY._options = None
  _PARTITIONINGPOLICYDESCRIPTION_LABELSENTRY._serialized_options = b'8\001'
  _EXECUTIONPOLICYDESCRIPTION_LABELSENTRY._options = None
  _EXECUTIONPOLICYDESCRIPTION_LABELSENTRY._serialized_options = b'8\001'
  _REPLICATIONPOLICYDESCRIPTION_LABELSENTRY._options = None
  _REPLICATIONPOLICYDESCRIPTION_LABELSENTRY._serialized_options = b'8\001'
  _CACHINGPOLICYDESCRIPTION_LABELSENTRY._options = None
  _CACHINGPOLICYDESCRIPTION_LABELSENTRY._serialized_options = b'8\001'
  _TABLEPROFILEDESCRIPTION_LABELSENTRY._options = None
  _TABLEPROFILEDESCRIPTION_LABELSENTRY._serialized_options = b'8\001'
  _EXECUTESCANQUERYREQUEST_PARAMETERSENTRY._options = None
  _EXECUTESCANQUERYREQUEST_PARAMETERSENTRY._serialized_options = b'8\001'
  _CREATESESSIONREQUEST._serialized_start=389
  _CREATESESSIONREQUEST._serialized_end=470
  _CREATESESSIONRESPONSE._serialized_start=472
  _CREATESESSIONRESPONSE._serialized_end=541
  _CREATESESSIONRESULT._serialized_start=543
  _CREATESESSIONRESULT._serialized_end=584
  _DELETESESSIONREQUEST._serialized_start=586
  _DELETESESSIONREQUEST._serialized_end=687
  _DELETESESSIONRESPONSE._serialized_start=689
  _DELETESESSIONRESPONSE._serialized_end=758
  _GLOBALINDEX._serialized_start=760
  _GLOBALINDEX._serialized_end=773
  _GLOBALASYNCINDEX._serialized_start=775
  _GLOBALASYNCINDEX._serialized_end=793
  _TABLEINDEX._serialized_start=796
  _TABLEINDEX._serialized_end=982
  _TABLEINDEXDESCRIPTION._serialized_start=985
  _TABLEINDEXDESCRIPTION._serialized_end=1332
  _TABLEINDEXDESCRIPTION_STATUS._serialized_start=1253
  _TABLEINDEXDESCRIPTION_STATUS._serialized_end=1324
  _INDEXBUILDSTATE._serialized_start=1335
  _INDEXBUILDSTATE._serialized_end=1556
  _INDEXBUILDSTATE_STATE._serialized_start=1355
  _INDEXBUILDSTATE_STATE._serialized_end=1556
  _INDEXBUILDDESCRIPTION._serialized_start=1558
  _INDEXBUILDDESCRIPTION._serialized_end=1633
  _INDEXBUILDMETADATA._serialized_start=1636
  _INDEXBUILDMETADATA._serialized_end=1778
  _CHANGEFEEDMODE._serialized_start=1781
  _CHANGEFEEDMODE._serialized_end=1935
  _CHANGEFEEDMODE_MODE._serialized_start=1800
  _CHANGEFEEDMODE_MODE._serialized_end=1935
  _CHANGEFEEDFORMAT._serialized_start=1937
  _CHANGEFEEDFORMAT._serialized_end=2006
  _CHANGEFEEDFORMAT_FORMAT._serialized_start=1957
  _CHANGEFEEDFORMAT_FORMAT._serialized_end=2006
  _CHANGEFEED._serialized_start=2009
  _CHANGEFEED._serialized_end=2214
  _CHANGEFEEDDESCRIPTION._serialized_start=2217
  _CHANGEFEEDDESCRIPTION._serialized_end=2506
  _CHANGEFEEDDESCRIPTION_STATE._serialized_start=2437
  _CHANGEFEEDDESCRIPTION_STATE._serialized_end=2506
  _STORAGEPOOL._serialized_start=2508
  _STORAGEPOOL._serialized_end=2536
  _STORAGEPOLICY._serialized_start=2539
  _STORAGEPOLICY._serialized_end=2837
  _COLUMNFAMILYPOLICY._serialized_start=2840
  _COLUMNFAMILYPOLICY._serialized_end=3145
  _COLUMNFAMILYPOLICY_COMPRESSION._serialized_start=3069
  _COLUMNFAMILYPOLICY_COMPRESSION._serialized_end=3145
  _COMPACTIONPOLICY._serialized_start=3147
  _COMPACTIONPOLICY._serialized_end=3186
  _EXPLICITPARTITIONS._serialized_start=3188
  _EXPLICITPARTITIONS._serialized_end=3247
  _PARTITIONSTATS._serialized_start=3249
  _PARTITIONSTATS._serialized_end=3308
  _TABLESTATS._serialized_start=3311
  _TABLESTATS._serialized_end=3544
  _PARTITIONINGPOLICY._serialized_start=3547
  _PARTITIONINGPOLICY._serialized_end=3895
  _PARTITIONINGPOLICY_AUTOPARTITIONINGPOLICY._serialized_start=3763
  _PARTITIONINGPOLICY_AUTOPARTITIONINGPOLICY._serialized_end=3881
  _EXECUTIONPOLICY._serialized_start=3897
  _EXECUTIONPOLICY._serialized_end=3935
  _REPLICATIONPOLICY._serialized_start=3938
  _REPLICATIONPOLICY._serialized_end=4115
  _CACHINGPOLICY._serialized_start=4117
  _CACHINGPOLICY._serialized_end=4153
  _TABLEPROFILE._serialized_start=4156
  _TABLEPROFILE._serialized_end=4519
  _COLUMNMETA._serialized_start=4521
  _COLUMNMETA._serialized_end=4588
  _DATETYPECOLUMNMODESETTINGS._serialized_start=4590
  _DATETYPECOLUMNMODESETTINGS._serialized_end=4669
  _VALUESINCEUNIXEPOCHMODESETTINGS._serialized_start=4672
  _VALUESINCEUNIXEPOCHMODESETTINGS._serialized_end=4942
  _VALUESINCEUNIXEPOCHMODESETTINGS_UNIT._serialized_start=4828
  _VALUESINCEUNIXEPOCHMODESETTINGS_UNIT._serialized_end=4942
  _TTLSETTINGS._serialized_start=4945
  _TTLSETTINGS._serialized_end=5141
  _STORAGESETTINGS._serialized_start=5144
  _STORAGESETTINGS._serialized_end=5362
  _COLUMNFAMILY._serialized_start=5365
  _COLUMNFAMILY._serialized_end=5625
  _COLUMNFAMILY_COMPRESSION._serialized_start=5540
  _COLUMNFAMILY_COMPRESSION._serialized_end=5625
  _PARTITIONINGSETTINGS._serialized_start=5628
  _PARTITIONINGSETTINGS._serialized_end=5875
  _AZREADREPLICASSETTINGS._serialized_start=5877
  _AZREADREPLICASSETTINGS._serialized_end=5944
  _CLUSTERREPLICASSETTINGS._serialized_start=5946
  _CLUSTERREPLICASSETTINGS._serialized_end=6041
  _READREPLICASSETTINGS._serialized_start=6043
  _READREPLICASSETTINGS._serialized_end=6159
  _CREATETABLEREQUEST._serialized_start=6162
  _CREATETABLEREQUEST._serialized_end=7022
  _CREATETABLEREQUEST_ATTRIBUTESENTRY._serialized_start=6959
  _CREATETABLEREQUEST_ATTRIBUTESENTRY._serialized_end=7008
  _CREATETABLERESPONSE._serialized_start=7024
  _CREATETABLERESPONSE._serialized_end=7091
  _DROPTABLEREQUEST._serialized_start=7093
  _DROPTABLEREQUEST._serialized_end=7210
  _DROPTABLERESPONSE._serialized_start=7212
  _DROPTABLERESPONSE._serialized_end=7277
  _RENAMEINDEXITEM._serialized_start=7279
  _RENAMEINDEXITEM._serialized_end=7372
  _ALTERTABLEREQUEST._serialized_start=7375
  _ALTERTABLEREQUEST._serialized_end=8459
  _ALTERTABLEREQUEST_ALTERATTRIBUTESENTRY._serialized_start=8391
  _ALTERTABLEREQUEST_ALTERATTRIBUTESENTRY._serialized_end=8445
  _ALTERTABLERESPONSE._serialized_start=8461
  _ALTERTABLERESPONSE._serialized_end=8527
  _COPYTABLEREQUEST._serialized_start=8530
  _COPYTABLEREQUEST._serialized_end=8674
  _COPYTABLERESPONSE._serialized_start=8676
  _COPYTABLERESPONSE._serialized_end=8741
  _COPYTABLEITEM._serialized_start=8743
  _COPYTABLEITEM._serialized_end=8827
  _COPYTABLESREQUEST._serialized_start=8830
  _COPYTABLESREQUEST._serialized_end=8970
  _COPYTABLESRESPONSE._serialized_start=8972
  _COPYTABLESRESPONSE._serialized_end=9038
  _RENAMETABLEITEM._serialized_start=9040
  _RENAMETABLEITEM._serialized_end=9133
  _RENAMETABLESREQUEST._serialized_start=9136
  _RENAMETABLESREQUEST._serialized_end=9280
  _RENAMETABLESRESPONSE._serialized_start=9282
  _RENAMETABLESRESPONSE._serialized_end=9350
  _DESCRIBETABLEREQUEST._serialized_start=9353
  _DESCRIBETABLEREQUEST._serialized_end=9564
  _DESCRIBETABLERESPONSE._serialized_start=9566
  _DESCRIBETABLERESPONSE._serialized_end=9635
  _DESCRIBETABLERESULT._serialized_start=9638
  _DESCRIBETABLERESULT._serialized_end=10401
  _DESCRIBETABLERESULT_ATTRIBUTESENTRY._serialized_start=6959
  _DESCRIBETABLERESULT_ATTRIBUTESENTRY._serialized_end=7008
  _QUERY._serialized_start=10403
  _QUERY._serialized_end=10453
  _SERIALIZABLEMODESETTINGS._serialized_start=10455
  _SERIALIZABLEMODESETTINGS._serialized_end=10481
  _ONLINEMODESETTINGS._serialized_start=10483
  _ONLINEMODESETTINGS._serialized_end=10537
  _STALEMODESETTINGS._serialized_start=10539
  _STALEMODESETTINGS._serialized_end=10558
  _SNAPSHOTMODESETTINGS._serialized_start=10560
  _SNAPSHOTMODESETTINGS._serialized_end=10582
  _TRANSACTIONSETTINGS._serialized_start=10585
  _TRANSACTIONSETTINGS._serialized_end=10868
  _TRANSACTIONCONTROL._serialized_start=10870
  _TRANSACTIONCONTROL._serialized_end=10993
  _QUERYCACHEPOLICY._serialized_start=10995
  _QUERYCACHEPOLICY._serialized_end=11036
  _QUERYSTATSCOLLECTION._serialized_start=11039
  _QUERYSTATSCOLLECTION._serialized_end=11216
  _QUERYSTATSCOLLECTION_MODE._serialized_start=11064
  _QUERYSTATSCOLLECTION_MODE._serialized_end=11216
  _EXECUTEDATAQUERYREQUEST._serialized_start=11219
  _EXECUTEDATAQUERYREQUEST._serialized_end=11665
  _EXECUTEDATAQUERYREQUEST_PARAMETERSENTRY._serialized_start=11599
  _EXECUTEDATAQUERYREQUEST_PARAMETERSENTRY._serialized_end=11665
  _EXECUTEDATAQUERYRESPONSE._serialized_start=11667
  _EXECUTEDATAQUERYRESPONSE._serialized_end=11739
  _EXECUTESCHEMEQUERYREQUEST._serialized_start=11741
  _EXECUTESCHEMEQUERYREQUEST._serialized_end=11865
  _EXECUTESCHEMEQUERYRESPONSE._serialized_start=11867
  _EXECUTESCHEMEQUERYRESPONSE._serialized_end=11941
  _TRANSACTIONMETA._serialized_start=11943
  _TRANSACTIONMETA._serialized_end=11972
  _QUERYMETA._serialized_start=11975
  _QUERYMETA._serialized_end=12134
  _QUERYMETA_PARAMETERSTYPESENTRY._serialized_start=12069
  _QUERYMETA_PARAMETERSTYPESENTRY._serialized_end=12134
  _EXECUTEQUERYRESULT._serialized_start=12137
  _EXECUTEQUERYRESULT._serialized_end=12330
  _EXPLAINDATAQUERYREQUEST._serialized_start=12332
  _EXPLAINDATAQUERYREQUEST._serialized_end=12454
  _EXPLAINDATAQUERYRESPONSE._serialized_start=12456
  _EXPLAINDATAQUERYRESPONSE._serialized_end=12528
  _EXPLAINQUERYRESULT._serialized_start=12530
  _EXPLAINQUERYRESULT._serialized_end=12589
  _PREPAREDATAQUERYREQUEST._serialized_start=12591
  _PREPAREDATAQUERYREQUEST._serialized_end=12713
  _PREPAREDATAQUERYRESPONSE._serialized_start=12715
  _PREPAREDATAQUERYRESPONSE._serialized_end=12787
  _PREPAREQUERYRESULT._serialized_start=12790
  _PREPAREQUERYRESULT._serialized_end=12973
  _PREPAREQUERYRESULT_PARAMETERSTYPESENTRY._serialized_start=12069
  _PREPAREQUERYRESULT_PARAMETERSTYPESENTRY._serialized_end=12134
  _KEEPALIVEREQUEST._serialized_start=12975
  _KEEPALIVEREQUEST._serialized_end=13072
  _KEEPALIVERESPONSE._serialized_start=13074
  _KEEPALIVERESPONSE._serialized_end=13139
  _KEEPALIVERESULT._serialized_start=13142
  _KEEPALIVERESULT._serialized_end=13325
  _KEEPALIVERESULT_SESSIONSTATUS._serialized_start=13227
  _KEEPALIVERESULT_SESSIONSTATUS._serialized_end=13325
  _BEGINTRANSACTIONREQUEST._serialized_start=13328
  _BEGINTRANSACTIONREQUEST._serialized_end=13485
  _BEGINTRANSACTIONRESPONSE._serialized_start=13487
  _BEGINTRANSACTIONRESPONSE._serialized_end=13559
  _BEGINTRANSACTIONRESULT._serialized_start=13561
  _BEGINTRANSACTIONRESULT._serialized_end=13630
  _COMMITTRANSACTIONREQUEST._serialized_start=13633
  _COMMITTRANSACTIONREQUEST._serialized_end=13814
  _COMMITTRANSACTIONRESPONSE._serialized_start=13816
  _COMMITTRANSACTIONRESPONSE._serialized_end=13889
  _COMMITTRANSACTIONRESULT._serialized_start=13891
  _COMMITTRANSACTIONRESULT._serialized_end=13965
  _ROLLBACKTRANSACTIONREQUEST._serialized_start=13967
  _ROLLBACKTRANSACTIONREQUEST._serialized_end=14089
  _ROLLBACKTRANSACTIONRESPONSE._serialized_start=14091
  _ROLLBACKTRANSACTIONRESPONSE._serialized_end=14166
  _STORAGEPOLICYDESCRIPTION._serialized_start=14169
  _STORAGEPOLICYDESCRIPTION._serialized_end=14321
  _STORAGEPOLICYDESCRIPTION_LABELSENTRY._serialized_start=14276
  _STORAGEPOLICYDESCRIPTION_LABELSENTRY._serialized_end=14321
  _COMPACTIONPOLICYDESCRIPTION._serialized_start=14324
  _COMPACTIONPOLICYDESCRIPTION._serialized_end=14482
  _COMPACTIONPOLICYDESCRIPTION_LABELSENTRY._serialized_start=14276
  _COMPACTIONPOLICYDESCRIPTION_LABELSENTRY._serialized_end=14321
  _PARTITIONINGPOLICYDESCRIPTION._serialized_start=14485
  _PARTITIONINGPOLICYDESCRIPTION._serialized_end=14647
  _PARTITIONINGPOLICYDESCRIPTION_LABELSENTRY._serialized_start=14276
  _PARTITIONINGPOLICYDESCRIPTION_LABELSENTRY._serialized_end=14321
  _EXECUTIONPOLICYDESCRIPTION._serialized_start=14650
  _EXECUTIONPOLICYDESCRIPTION._serialized_end=14806
  _EXECUTIONPOLICYDESCRIPTION_LABELSENTRY._serialized_start=14276
  _EXECUTIONPOLICYDESCRIPTION_LABELSENTRY._serialized_end=14321
  _REPLICATIONPOLICYDESCRIPTION._serialized_start=14809
  _REPLICATIONPOLICYDESCRIPTION._serialized_end=14969
  _REPLICATIONPOLICYDESCRIPTION_LABELSENTRY._serialized_start=14276
  _REPLICATIONPOLICYDESCRIPTION_LABELSENTRY._serialized_end=14321
  _CACHINGPOLICYDESCRIPTION._serialized_start=14972
  _CACHINGPOLICYDESCRIPTION._serialized_end=15124
  _CACHINGPOLICYDESCRIPTION_LABELSENTRY._serialized_start=14276
  _CACHINGPOLICYDESCRIPTION_LABELSENTRY._serialized_end=14321
  _TABLEPROFILEDESCRIPTION._serialized_start=15127
  _TABLEPROFILEDESCRIPTION._serialized_end=15701
  _TABLEPROFILEDESCRIPTION_LABELSENTRY._serialized_start=14276
  _TABLEPROFILEDESCRIPTION_LABELSENTRY._serialized_end=14321
  _DESCRIBETABLEOPTIONSREQUEST._serialized_start=15703
  _DESCRIBETABLEOPTIONSREQUEST._serialized_end=15791
  _DESCRIBETABLEOPTIONSRESPONSE._serialized_start=15793
  _DESCRIBETABLEOPTIONSRESPONSE._serialized_end=15869
  _DESCRIBETABLEOPTIONSRESULT._serialized_start=15872
  _DESCRIBETABLEOPTIONSRESULT._serialized_end=16409
  _KEYRANGE._serialized_start=16412
  _KEYRANGE._serialized_end=16604
  _READTABLEREQUEST._serialized_start=16607
  _READTABLEREQUEST._serialized_end=16799
  _READTABLERESPONSE._serialized_start=16802
  _READTABLERESPONSE._serialized_end=16990
  _READTABLERESULT._serialized_start=16992
  _READTABLERESULT._serialized_end=17045
  _BULKUPSERTREQUEST._serialized_start=17048
  _BULKUPSERTREQUEST._serialized_end=17317
  _BULKUPSERTRESPONSE._serialized_start=17319
  _BULKUPSERTRESPONSE._serialized_end=17385
  _BULKUPSERTRESULT._serialized_start=17387
  _BULKUPSERTRESULT._serialized_end=17405
  _EXECUTESCANQUERYREQUEST._serialized_start=17408
  _EXECUTESCANQUERYREQUEST._serialized_end=17809
  _EXECUTESCANQUERYREQUEST_PARAMETERSENTRY._serialized_start=11599
  _EXECUTESCANQUERYREQUEST_PARAMETERSENTRY._serialized_end=11665
  _EXECUTESCANQUERYREQUEST_MODE._serialized_start=17724
  _EXECUTESCANQUERYREQUEST_MODE._serialized_end=17785
  _EXECUTESCANQUERYPARTIALRESPONSE._serialized_start=17812
  _EXECUTESCANQUERYPARTIALRESPONSE._serialized_end=17987
  _EXECUTESCANQUERYPARTIALRESULT._serialized_start=17990
  _EXECUTESCANQUERYPARTIALRESULT._serialized_end=18130
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# flake8: noqa
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: ydb_table_v1.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from ydb._grpc.v3.protos import ydb_table_pb2 as protos_dot_ydb__table__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='ydb_table_v1.proto',
  package='Ydb.Table.V1',
  syntax='proto3',
  serialized_options=b'\n\021tech.ydb.table.v1Z4github.com/ydb-platform/ydb-go-genproto/Ydb_Table_V1',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n\x12ydb_table_v1.proto\x12\x0cYdb.Table.V1\x1a\x16protos/ydb_table.proto2\xa4\x0e\n\x0cTableService\x12R\n\rCreateSession\x12\x1f.Ydb.Table.CreateSessionRequest\x1a .Ydb.Table.CreateSessionResponse\x12R\n\rDeleteSession\x12\x1f.Ydb.Table.DeleteSessionRequest\x1a .Ydb.Table.DeleteSessionResponse\x12\x46\n\tKeepAlive\x12\x1b.Ydb.Table.KeepAliveRequest\x1a\x1c.Ydb.Table.KeepAliveResponse\x12L\n\x0b\x43reateTable\x12\x1d.Ydb.Table.CreateTableRequest\x1a\x1e.Ydb.Table.CreateTableResponse\x12\x46\n\tDropTable\x12\x1b.Ydb.Table.DropTableRequest\x1a\x1c.Ydb.Table.DropTableResponse\x12I\n\nAlterTable\x12\x1c.Ydb.Table.AlterTableRequest\x1a\x1d.Ydb.Table.AlterTableResponse\x12\x46\n\tCopyTable\x12\x1b.Ydb.Table.CopyTableRequest\x1a\x1c.Ydb.Table.CopyTableResponse\x12I\n\nCopyTables\x12\x1c.Ydb.Table.CopyTablesRequest\x1a\x1d.Ydb.Table.CopyTablesResponse\x12O\n\x0cRenameTables\x12\x1e.Ydb.Table.RenameTablesRequest\x1a\x1f.Ydb.Table.RenameTablesResponse\x12R\n\rDescribeTable\x12\x1f.Ydb.Table.DescribeTableRequest\x1a .Ydb.Table.DescribeTableResponse\x12[\n\x10\x45xplainDataQuery\x12\".Ydb.Table.ExplainDataQueryRequest\x1a#.Ydb.Table.ExplainDataQueryResponse\x12[\n\x10PrepareDataQuery\x12\".Ydb.Table.PrepareDataQueryRequest\x1a#.Ydb.Table.PrepareDataQueryResponse\x12[\n\x10\x45xecuteDataQuery\x12\".Ydb.Table.ExecuteDataQueryRequest\x1a#.Ydb.Table.ExecuteDataQueryResponse\x12\x61\n\x12\x45xecuteSchemeQuery\x12$.Ydb.Table.ExecuteSchemeQueryRequest\x1a%.Ydb.Table.ExecuteSchemeQueryResponse\x12[\n\x10\x42\x65ginTransaction\x12\".Ydb.Table.BeginTransactionRequest\x1a#.Ydb.Table.BeginTransactionResponse\x12^\n\x11\x43ommitTransaction\x12#.Ydb.Table.CommitTransactionRequest\x1a$.Ydb.Table.CommitTransactionResponse\x12\x64\n\x13RollbackTransaction\x12%.Ydb.Table.RollbackTransactionRequest\x1a&.Ydb.Table.RollbackTransactionResponse\x12g\n\x14\x44\x65scribeTableOptions\x12&.Ydb.Table.DescribeTableOptionsRequest\x1a\'.Ydb.Table.DescribeTableOptionsResponse\x12N\n\x0fStreamReadTable\x12\x1b.Ydb.Table.ReadTableRequest\x1a\x1c.Ydb.Table.ReadTableResponse0\x01\x12I\n\nBulkUpsert\x12\x1c.Ydb.Table.BulkUpsertRequest\x1a\x1d.Ydb.Table.BulkUpsertResponse\x12j\n\x16StreamExecuteScanQuery\x12\".Ydb.Table.ExecuteScanQueryRequest\x1a*.Ydb.Table.ExecuteScanQueryPartialResponse0\x01\x42I\n\x11tech.ydb.table.v1Z4github.com/ydb-platform/ydb-go-genproto/Ydb_Table_V1b\x06proto3'
  ,
  dependencies=[protos_dot_ydb__table__pb2.DESCRIPTOR,])



_sym_db.RegisterFileDescriptor(DESCRIPTOR)


DESCRIPTOR._options = None

_TABLESERVICE = _descriptor.ServiceDescriptor(
  name='TableService',
  full_name='Ydb.Table.V1.TableService',
  file=DESCRIPTOR,
  index=0,
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_start=61,
  serialized_end=1889,
  methods=[
  _descriptor.MethodDescriptor(
    name='CreateSession',
    full_name='Ydb.Table.V1.TableService.CreateSession',
    index=0,
    containing_service=None,
    input_type=protos_dot_ydb__table__pb2._CREATESESSIONREQUEST,
    output_type=protos_dot_ydb__table__pb2._CREATESESSIONRESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='DeleteSession',
    full_name='Ydb.Table.V1.TableService.DeleteSession',
    index=1,
    containing_service=None,
    input_type=protos_dot_ydb__table__pb2._DELETESESSIONREQUEST,
    output_type=protos_dot_ydb__table__pb2._DELETESESSIONRESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='KeepAlive',
    full_name='Ydb.Table.V1.TableService.KeepAlive',
    index=2,
    containing_service=None,
    input_type=protos_dot_ydb__table__pb2._KEEPALIVEREQUEST,
    output_type=protos_dot_ydb__table__pb2._KEEPALIVERESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='CreateTable',
    full_name='Ydb.Table.V1.TableService.CreateTable',
    index=3,
    containing_service=None,
    input_type=protos_dot_ydb__table__pb2._CREATETABLEREQUEST,
    output_type=protos_dot_ydb__table__pb2._CREATETABLERESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='DropTable',
    full_name='Ydb.Table.V1.TableService.DropTable',
    index=4,
    containing_service=None,
    input_type=protos_dot_ydb__table__pb2._DROPTABLEREQUEST,
    output_type=protos_dot_ydb__table__pb2._DROPTABLERESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='AlterTable',
    full_name='Ydb.Table.V1.TableService.AlterTable',
    index=5,
    containing_service=None,
    input_type=protos_dot_ydb__table__pb2._ALTERTABLEREQUEST,
    output_type=protos_dot_ydb__table__pb2._ALTERTABLERESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='CopyTable',
    full_name='Ydb.Table.V1.TableService.CopyTable',
    index=6,
    containing_service=None,
    input_type=protos_dot_ydb__table__pb2._COPYTABLEREQUEST,
    output_type=protos_dot_ydb__table__pb2._COPYTABLERESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='CopyTables',
    full_name='Ydb.Table.V1.TableService.CopyTables',
    index=7,
    containing_service=None,
    input_type=protos_dot_ydb__table__pb2._COPYTABLESREQUEST,
    output_type=protos_dot_ydb__table__pb2._COPYTABLESRESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='RenameTables',
    full_name='Ydb.Table.V1.TableService.RenameTables',
    index=8,
    containing_service=None,
    input_type=protos_dot_ydb__table__pb2._RENAMETABLESREQUEST,
    output_type=protos_dot_ydb__table__pb2._RENAMETABLESRESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='DescribeTable',
    full_name='Ydb.Table.V1.TableService.DescribeTable',
    index=9,
    containing_service=None,
    input_type=protos_dot_ydb__table__pb2._DESCRIBETABLEREQUEST,
    output_type=protos_dot_ydb__table__pb2._DESCRIBETABLERESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='ExplainDataQuery',
    full_name='Ydb.Table.V1.TableService.ExplainDataQuery',
    index=10,
    containing_service=None,
    input_type=protos_dot_ydb__table__pb2._EXPLAINDATAQUERYREQUEST,
    output_type=protos_dot_ydb__table__pb2._EXPLAINDATAQUERYRESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='PrepareDataQuery',
    full_name='Ydb.Table.V1.TableService.PrepareDataQuery',
    index=11,
    containing_service=None,
    input_type=protos_dot_ydb__table__pb2._PREPAREDATAQUERYREQUEST,
    output_type=protos_dot_ydb__table__pb2._PREPAREDATAQUERYRESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='ExecuteDataQuery',
    full_name='Ydb.Table.V1.TableService.ExecuteDataQuery',
    index=12,
    containing_service=None,
    input_type=protos_dot_ydb__table__pb2._EXECUTEDATAQUERYREQUEST,
    output_type=protos_dot_ydb__table__pb2._EXECUTEDATAQUERYRESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='ExecuteSchemeQuery',
    full_name='Ydb.Table.V1.TableService.ExecuteSchemeQuery',
    index=13,
    containing_service=None,
    input_type=protos_dot_ydb__table__pb2._EXECUTESCHEMEQUERYREQUEST,
    output_type=protos_dot_ydb__table__pb2._EXECUTESCHEMEQUERYRESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='BeginTransaction',
    full_name='Ydb.Table.V1.TableService.BeginTransaction',
    index=14,
    containing_service=None,
    input_type=protos_dot_ydb__table__pb2._BEGINTRANSACTIONREQUEST,
    output_type=protos_dot_ydb__table__pb2._BEGINTRANSACTIONRESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='CommitTransaction',
    full_name='Ydb.Table.V1.TableService.CommitTransaction',
    index=15,
    containing_service=None,
    input_type=protos_dot_ydb__table__pb2._COMMITTRANSACTIONREQUEST,
    output_type=protos_dot_ydb__table__pb2._COMMITTRANSACTIONRESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='RollbackTransaction',
    full_name='Ydb.Table.V1.TableService.RollbackTransaction',
    index=16,
    containing_service=None,
    input_type=protos_dot_ydb__table__pb2._ROLLBACKTRANSACTIONREQUEST,
    output_type=protos_dot_ydb__table__pb2._ROLLBACKTRANSACTIONRESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='DescribeTableOptions',
    full_name='Ydb.Table.V1.TableService.DescribeTableOptions',
    index=17,
    containing_service=None,
    input_type=protos_dot_ydb__table__pb2._DESCRIBETABLEOPTIONSREQUEST,
    output_type=protos_dot_ydb__table__pb2._DESCRIBETABLEOPTIONSRESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='StreamReadTable',
    full_name='Ydb.Table.V1.TableService.StreamReadTable',
    index=18,
    containing_service=None,
    input_type=protos_dot_ydb__table__pb2._READTABLEREQUEST,
    output_type=protos_dot_ydb__table__pb2._READTABLERESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='BulkUpsert',
    full_name='Ydb.Table.V1.TableService.BulkUpsert',
    index=19,
    containing_service=None,
    input_type=protos_dot_ydb__table__pb2._BULKUPSERTREQUEST,
    output_type=protos_dot_ydb__table__pb2._BULKUPSERTRESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='StreamExecuteScanQuery',
    full_name='Ydb.Table.V1.TableService.StreamExecuteScanQuery',
    index=20,
    containing_service=None,
    input_type=protos_dot_ydb__table__pb2._EXECUTESCANQUERYREQUEST,
    output_type=protos_dot_ydb__table__pb2._EXECUTESCANQUERYPARTIALRESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
])
_sym_db.RegisterServiceDescriptor(_TABLESERVICE)

DESCRIPTOR.services_by_name['TableService'] = _TABLESERVICE

# @@protoc_insertion_point(module_scope)
